@@ -60,6 +60,11 @@ import docs315Config from '../../../site_config/docs3-1-5';
 import docs316Config from '../../../site_config/docs3-1-6';
 import docs317Config from '../../../site_config/docs3-1-7';
 import docs318Config from '../../../site_config/docs3-1-8';
+import docs319Config from '../../../site_config/docs3-1-9';
+import docs320Config from '../../../site_config/docs3-2-0';
+import docs321Config from '../../../site_config/docs3-2-1';
+import docs322Config from '../../../site_config/docs3-2-2';
+import docs330Config from '../../../site_config/docs3-3-0-alpha';
 import docsDevConfig from '../../../site_config/docsdev';
 
 const docsSource = {
@@ -96,6 +101,11 @@ const docsSource = {
   '3.1.6': docs316Config,
   '3.1.7': docs317Config,
   '3.1.8': docs318Config,
+  '3.1.9': docs319Config,
+  '3.2.0': docs320Config,
+  '3.2.1': docs321Config,
+  '3.2.2': docs322Config,
+  '3.3.0-alpha': docs330Config,
   dev: docsDevConfig,
 };
 
