@@ -18,32 +18,33 @@
 package org.apache.dolphinscheduler.api.interceptor;
 
 import org.apache.dolphinscheduler.api.enums.Status;
+import org.apache.dolphinscheduler.api.metrics.ApiServerMetrics;
 import org.apache.dolphinscheduler.api.security.Authenticator;
-import org.apache.dolphinscheduler.common.Constants;
+import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.Flag;
 import org.apache.dolphinscheduler.common.thread.ThreadLocalContext;
 import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.dolphinscheduler.dao.mapper.UserMapper;
 
-import org.apache.commons.httpclient.HttpStatus;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
+import org.apache.http.HttpStatus;
+
+import java.util.Date;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
+
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.web.servlet.HandlerInterceptor;
 import org.springframework.web.servlet.ModelAndView;
 
-import java.util.Date;
-
 /**
  * login interceptor, must log in first
  */
+@Slf4j
 public class LoginHandlerInterceptor implements HandlerInterceptor {
-    private static final Logger logger = LoggerFactory.getLogger(LoginHandlerInterceptor.class);
 
     @Autowired
     private UserMapper userMapper;
@@ -61,6 +62,8 @@ public class LoginHandlerInterceptor implements HandlerInterceptor {
      */
     @Override
     public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) {
+        ApiServerMetrics.incApiRequestCount();
+
         // get token
         String token = request.getHeader("token");
         User user;
@@ -69,14 +72,14 @@ public class LoginHandlerInterceptor implements HandlerInterceptor {
             // if user is null
             if (user == null) {
                 response.setStatus(HttpStatus.SC_UNAUTHORIZED);
-                logger.info("user does not exist");
+                log.info("user does not exist");
                 return false;
             }
         } else {
             user = userMapper.queryUserByToken(token, new Date());
             if (user == null) {
                 response.setStatus(HttpStatus.SC_UNAUTHORIZED);
-                logger.info("user token has expired");
+                log.info("user token has expired");
                 return false;
             }
         }
@@ -84,7 +87,7 @@ public class LoginHandlerInterceptor implements HandlerInterceptor {
         // check user state
         if (user.getState() == Flag.NO.ordinal()) {
             response.setStatus(HttpStatus.SC_UNAUTHORIZED);
-            logger.info(Status.USER_DISABLED.getMsg());
+            log.info(Status.USER_DISABLED.getMsg());
             return false;
         }
         request.setAttribute(Constants.SESSION_USER, user);
@@ -93,7 +96,21 @@ public class LoginHandlerInterceptor implements HandlerInterceptor {
     }
 
     @Override
-    public void postHandle(HttpServletRequest request, HttpServletResponse response, Object handler, ModelAndView modelAndView) throws Exception {
+    public void postHandle(HttpServletRequest request,
+                           HttpServletResponse response,
+                           Object handler,
+                           ModelAndView modelAndView) {
         ThreadLocalContext.getTimezoneThreadLocal().remove();
+
+        int code = response.getStatus();
+        if (code >= 200 && code < 300) {
+            ApiServerMetrics.incApiResponse2xxCount();
+        } else if (code >= 300 && code < 400) {
+            ApiServerMetrics.incApiResponse3xxCount();
+        } else if (code >= 400 && code < 500) {
+            ApiServerMetrics.incApiResponse4xxCount();
+        } else if (code >= 500 && code < 600) {
+            ApiServerMetrics.incApiResponse5xxCount();
+        }
     }
 }
