@@ -23,6 +23,7 @@ import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationCon
 
 import org.apache.dolphinscheduler.api.dto.EnvironmentDto;
 import org.apache.dolphinscheduler.api.enums.Status;
+import org.apache.dolphinscheduler.api.exceptions.ServiceException;
 import org.apache.dolphinscheduler.api.service.EnvironmentService;
 import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.api.utils.Result;
@@ -30,7 +31,6 @@ import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.UserType;
 import org.apache.dolphinscheduler.common.utils.CodeGenerateUtils;
-import org.apache.dolphinscheduler.common.utils.CodeGenerateUtils.CodeGenerateException;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.dao.entity.Environment;
 import org.apache.dolphinscheduler.dao.entity.EnvironmentWorkerGroupRelation;
@@ -95,28 +95,22 @@ public class EnvironmentServiceImpl extends BaseServiceImpl implements Environme
      */
     @Override
     @Transactional
-    public Map<String, Object> createEnvironment(User loginUser, String name, String config, String desc,
-                                                 String workerGroups) {
-        Map<String, Object> result = new HashMap<>();
+    public Long createEnvironment(User loginUser,
+                                  String name,
+                                  String config,
+                                  String desc,
+                                  String workerGroups) {
         if (!canOperatorPermissions(loginUser, null, AuthorizationType.ENVIRONMENT, ENVIRONMENT_CREATE)) {
-            putMsg(result, Status.USER_NO_OPERATION_PERM);
-            return result;
+            throw new ServiceException(Status.USER_NO_OPERATION_PERM);
         }
         if (checkDescriptionLength(desc)) {
-            log.warn("Parameter description is too long.");
-            putMsg(result, Status.DESCRIPTION_TOO_LONG_ERROR);
-            return result;
-        }
-        Map<String, Object> checkResult = checkParams(name, config, workerGroups);
-        if (checkResult.get(Constants.STATUS) != Status.SUCCESS) {
-            return checkResult;
+            throw new ServiceException(Status.DESCRIPTION_TOO_LONG_ERROR);
         }
+        checkParams(name, config, workerGroups);
 
         Environment environment = environmentMapper.queryByEnvironmentName(name);
         if (environment != null) {
-            log.warn("Environment with the same name already exist, environmentName:{}.", environment.getName());
-            putMsg(result, Status.ENVIRONMENT_NAME_EXISTS, name);
-            return result;
+            throw new ServiceException(Status.ENVIRONMENT_NAME_EXISTS, name);
         }
 
         Environment env = new Environment();
@@ -126,17 +120,7 @@ public class EnvironmentServiceImpl extends BaseServiceImpl implements Environme
         env.setOperator(loginUser.getId());
         env.setCreateTime(new Date());
         env.setUpdateTime(new Date());
-        long code = 0L;
-        try {
-            code = CodeGenerateUtils.getInstance().genCode();
-            env.setCode(code);
-        } catch (CodeGenerateException e) {
-            log.error("Generate environment code error.", e);
-        }
-        if (code == 0L) {
-            putMsg(result, Status.INTERNAL_SERVER_ERROR_ARGS, "Error generating environment code");
-            return result;
-        }
+        env.setCode(CodeGenerateUtils.genCode());
 
         if (environmentMapper.insert(env) > 0) {
             if (!StringUtils.isEmpty(workerGroups)) {
@@ -159,16 +143,9 @@ public class EnvironmentServiceImpl extends BaseServiceImpl implements Environme
                     });
                 }
             }
-            result.put(Constants.DATA_LIST, env.getCode());
-            putMsg(result, Status.SUCCESS);
-            permissionPostHandle(AuthorizationType.ENVIRONMENT, loginUser.getId(),
-                    Collections.singletonList(env.getId()), log);
-            log.info("Environment create complete, name:{}.", env.getName());
-        } else {
-            log.error("Environment create error, name:{}.", env.getName());
-            putMsg(result, Status.CREATE_ENVIRONMENT_ERROR);
+            return env.getCode();
         }
-        return result;
+        throw new ServiceException(Status.CREATE_ENVIRONMENT_ERROR);
     }
 
     /**
@@ -366,29 +343,20 @@ public class EnvironmentServiceImpl extends BaseServiceImpl implements Environme
      */
     @Transactional
     @Override
-    public Map<String, Object> updateEnvironmentByCode(User loginUser, Long code, String name, String config,
-                                                       String desc, String workerGroups) {
-        Map<String, Object> result = new HashMap<>();
+    public Environment updateEnvironmentByCode(User loginUser, Long code, String name, String config,
+                                               String desc, String workerGroups) {
         if (!canOperatorPermissions(loginUser, null, AuthorizationType.ENVIRONMENT, ENVIRONMENT_UPDATE)) {
-            putMsg(result, Status.USER_NO_OPERATION_PERM);
-            return result;
+            throw new ServiceException(Status.USER_NO_OPERATION_PERM);
         }
 
-        Map<String, Object> checkResult = checkParams(name, config, workerGroups);
-        if (checkResult.get(Constants.STATUS) != Status.SUCCESS) {
-            return checkResult;
-        }
+        checkParams(name, config, workerGroups);
         if (checkDescriptionLength(desc)) {
-            log.warn("Parameter description is too long.");
-            putMsg(result, Status.DESCRIPTION_TOO_LONG_ERROR);
-            return result;
+            throw new ServiceException(Status.DESCRIPTION_TOO_LONG_ERROR);
         }
 
         Environment environment = environmentMapper.queryByEnvironmentName(name);
         if (environment != null && !environment.getCode().equals(code)) {
-            log.warn("Environment with the same name already exist, name:{}.", environment.getName());
-            putMsg(result, Status.ENVIRONMENT_NAME_EXISTS, name);
-            return result;
+            throw new ServiceException(Status.ENVIRONMENT_NAME_EXISTS, name);
         }
 
         Set<String> workerGroupSet;
@@ -402,17 +370,14 @@ public class EnvironmentServiceImpl extends BaseServiceImpl implements Environme
         Set<String> existWorkerGroupSet = relationMapper
                 .queryByEnvironmentCode(code)
                 .stream()
-                .map(item -> item.getWorkerGroup())
+                .map(EnvironmentWorkerGroupRelation::getWorkerGroup)
                 .collect(Collectors.toSet());
 
         Set<String> deleteWorkerGroupSet = SetUtils.difference(existWorkerGroupSet, workerGroupSet).toSet();
         Set<String> addWorkerGroupSet = SetUtils.difference(workerGroupSet, existWorkerGroupSet).toSet();
 
         // verify whether the relation of this environment and worker groups can be adjusted
-        checkResult = checkUsedEnvironmentWorkerGroupRelation(deleteWorkerGroupSet, name, code);
-        if (checkResult.get(Constants.STATUS) != Status.SUCCESS) {
-            return checkResult;
-        }
+        checkUsedEnvironmentWorkerGroupRelation(deleteWorkerGroupSet, name, code);
 
         Environment env = new Environment();
         env.setCode(code);
@@ -424,33 +389,29 @@ public class EnvironmentServiceImpl extends BaseServiceImpl implements Environme
 
         int update =
                 environmentMapper.update(env, new UpdateWrapper<Environment>().lambda().eq(Environment::getCode, code));
-        if (update > 0) {
-            deleteWorkerGroupSet.stream().forEach(key -> {
-                if (StringUtils.isNotEmpty(key)) {
-                    relationMapper.delete(new QueryWrapper<EnvironmentWorkerGroupRelation>()
-                            .lambda()
-                            .eq(EnvironmentWorkerGroupRelation::getEnvironmentCode, code)
-                            .eq(EnvironmentWorkerGroupRelation::getWorkerGroup, key));
-                }
-            });
-            addWorkerGroupSet.stream().forEach(key -> {
-                if (StringUtils.isNotEmpty(key)) {
-                    EnvironmentWorkerGroupRelation relation = new EnvironmentWorkerGroupRelation();
-                    relation.setEnvironmentCode(code);
-                    relation.setWorkerGroup(key);
-                    relation.setUpdateTime(new Date());
-                    relation.setCreateTime(new Date());
-                    relation.setOperator(loginUser.getId());
-                    relationMapper.insert(relation);
-                }
-            });
-            log.info("Environment and relations update complete, environmentId:{}.", env.getId());
-            putMsg(result, Status.SUCCESS);
-        } else {
-            log.error("Environment update error, environmentId:{}.", env.getId());
-            putMsg(result, Status.UPDATE_ENVIRONMENT_ERROR, name);
+        if (update <= 0) {
+            throw new ServiceException(Status.UPDATE_ENVIRONMENT_ERROR, name);
         }
-        return result;
+        deleteWorkerGroupSet.forEach(key -> {
+            if (StringUtils.isNotEmpty(key)) {
+                relationMapper.delete(new QueryWrapper<EnvironmentWorkerGroupRelation>()
+                        .lambda()
+                        .eq(EnvironmentWorkerGroupRelation::getEnvironmentCode, code)
+                        .eq(EnvironmentWorkerGroupRelation::getWorkerGroup, key));
+            }
+        });
+        addWorkerGroupSet.forEach(key -> {
+            if (StringUtils.isNotEmpty(key)) {
+                EnvironmentWorkerGroupRelation relation = new EnvironmentWorkerGroupRelation();
+                relation.setEnvironmentCode(code);
+                relation.setWorkerGroup(key);
+                relation.setUpdateTime(new Date());
+                relation.setCreateTime(new Date());
+                relation.setOperator(loginUser.getId());
+                relationMapper.insert(relation);
+            }
+        });
+        return env;
     }
 
     /**
@@ -480,9 +441,8 @@ public class EnvironmentServiceImpl extends BaseServiceImpl implements Environme
         return result;
     }
 
-    private Map<String, Object> checkUsedEnvironmentWorkerGroupRelation(Set<String> deleteKeySet,
-                                                                        String environmentName, Long environmentCode) {
-        Map<String, Object> result = new HashMap<>();
+    private void checkUsedEnvironmentWorkerGroupRelation(Set<String> deleteKeySet,
+                                                         String environmentName, Long environmentCode) {
         for (String workerGroup : deleteKeySet) {
             List<TaskDefinition> taskDefinitionList = taskDefinitionMapper
                     .selectList(new QueryWrapper<TaskDefinition>().lambda()
@@ -492,41 +452,27 @@ public class EnvironmentServiceImpl extends BaseServiceImpl implements Environme
             if (Objects.nonNull(taskDefinitionList) && taskDefinitionList.size() != 0) {
                 Set<String> collect =
                         taskDefinitionList.stream().map(TaskDefinition::getName).collect(Collectors.toSet());
-                log.warn("Environment {} and worker group {} is being used by task {}, so can not update.",
-                        taskDefinitionList.get(0).getEnvironmentCode(), taskDefinitionList.get(0).getWorkerGroup(),
-                        collect);
-                putMsg(result, Status.UPDATE_ENVIRONMENT_WORKER_GROUP_RELATION_ERROR, workerGroup, environmentName,
-                        collect);
-                return result;
+                throw new ServiceException(Status.UPDATE_ENVIRONMENT_WORKER_GROUP_RELATION_ERROR, workerGroup,
+                        environmentName, collect);
             }
         }
-        result.put(Constants.STATUS, Status.SUCCESS);
-        return result;
     }
 
-    public Map<String, Object> checkParams(String name, String config, String workerGroups) {
-        Map<String, Object> result = new HashMap<>();
+    protected void checkParams(String name, String config, String workerGroups) {
         if (StringUtils.isEmpty(name)) {
-            log.warn("parameter environment name is empty.");
-            putMsg(result, Status.ENVIRONMENT_NAME_IS_NULL);
-            return result;
+            throw new ServiceException(Status.ENVIRONMENT_NAME_IS_NULL);
         }
         if (StringUtils.isEmpty(config)) {
-            log.warn("parameter environment config is empty.");
-            putMsg(result, Status.ENVIRONMENT_CONFIG_IS_NULL);
-            return result;
+            throw new ServiceException(Status.ENVIRONMENT_CONFIG_IS_NULL);
         }
-        if (!StringUtils.isEmpty(workerGroups)) {
-            List<String> workerGroupList = JSONUtils.parseObject(workerGroups, new TypeReference<List<String>>() {
-            });
-            if (Objects.isNull(workerGroupList)) {
-                log.warn("Parameter worker groups list is invalid.");
-                putMsg(result, Status.ENVIRONMENT_WORKER_GROUPS_IS_INVALID);
-                return result;
+        if (StringUtils.isNotEmpty(workerGroups)) {
+            try {
+                JSONUtils.parseObject(workerGroups, new TypeReference<List<String>>() {
+                });
+            } catch (IllegalArgumentException e) {
+                throw new ServiceException(Status.ENVIRONMENT_WORKER_GROUPS_IS_INVALID);
             }
         }
-        result.put(Constants.STATUS, Status.SUCCESS);
-        return result;
     }
 
 }
