@@ -18,10 +18,8 @@
 package org.apache.dolphinscheduler.api.service.impl;
 
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.FORCED_SUCCESS;
-import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.INSTANCE_UPDATE;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.TASK_INSTANCE;
 
-import org.apache.dolphinscheduler.api.dto.taskInstance.TaskInstanceRemoveCacheResponse;
 import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.exceptions.ServiceException;
 import org.apache.dolphinscheduler.api.service.ProjectService;
@@ -32,38 +30,32 @@ import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.TaskExecuteType;
-import org.apache.dolphinscheduler.common.utils.CollectionUtils;
 import org.apache.dolphinscheduler.common.utils.DateUtils;
-import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
 import org.apache.dolphinscheduler.dao.entity.Project;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
 import org.apache.dolphinscheduler.dao.entity.User;
+import org.apache.dolphinscheduler.dao.entity.WorkflowInstance;
 import org.apache.dolphinscheduler.dao.mapper.ProjectMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskDefinitionMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskInstanceMapper;
-import org.apache.dolphinscheduler.dao.repository.DqExecuteResultDao;
-import org.apache.dolphinscheduler.dao.repository.ProcessInstanceDao;
 import org.apache.dolphinscheduler.dao.repository.TaskInstanceDao;
-import org.apache.dolphinscheduler.dao.utils.TaskCacheUtils;
-import org.apache.dolphinscheduler.extract.base.client.SingletonJdkDynamicRpcClientProxyFactory;
+import org.apache.dolphinscheduler.dao.repository.WorkflowInstanceDao;
+import org.apache.dolphinscheduler.extract.base.client.Clients;
 import org.apache.dolphinscheduler.extract.common.ILogService;
+import org.apache.dolphinscheduler.extract.worker.IPhysicalTaskExecutorOperator;
 import org.apache.dolphinscheduler.extract.worker.IStreamingTaskInstanceOperator;
-import org.apache.dolphinscheduler.extract.worker.ITaskInstanceOperator;
-import org.apache.dolphinscheduler.extract.worker.transportor.TaskInstanceKillRequest;
-import org.apache.dolphinscheduler.extract.worker.transportor.TaskInstanceKillResponse;
 import org.apache.dolphinscheduler.extract.worker.transportor.TaskInstanceTriggerSavepointRequest;
 import org.apache.dolphinscheduler.extract.worker.transportor.TaskInstanceTriggerSavepointResponse;
 import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 import org.apache.dolphinscheduler.service.process.ProcessService;
+import org.apache.dolphinscheduler.task.executor.operations.TaskExecutorKillRequest;
+import org.apache.dolphinscheduler.task.executor.operations.TaskExecutorKillResponse;
 
 import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.lang3.tuple.Pair;
 
 import java.util.Date;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
 import java.util.stream.Collectors;
 
 import lombok.extern.slf4j.Slf4j;
@@ -75,9 +67,6 @@ import org.springframework.transaction.annotation.Transactional;
 import com.baomidou.mybatisplus.core.metadata.IPage;
 import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 
-/**
- * task instance service impl
- */
 @Service
 @Slf4j
 public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInstanceService {
@@ -103,21 +92,18 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
     @Autowired
     TaskDefinitionMapper taskDefinitionMapper;
 
-    @Autowired
-    private DqExecuteResultDao dqExecuteResultDao;
-
     @Autowired
     private TaskGroupQueueService taskGroupQueueService;
 
     @Autowired
-    private ProcessInstanceDao workflowInstanceDao;
+    private WorkflowInstanceDao workflowInstanceDao;
 
     /**
-     * query task list by project, process instance, task name, task start time, task end time, task status, keyword paging
+     * query task list by project, workflow instance, task name, task start time, task end time, task status, keyword paging
      *
      * @param loginUser         login user
      * @param projectCode       project code
-     * @param processInstanceId process instance id
+     * @param workflowInstanceId workflow instance id
      * @param searchVal         search value
      * @param taskName          task name
      * @param taskCode          task code
@@ -132,9 +118,9 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
     @Override
     public Result queryTaskListPaging(User loginUser,
                                       long projectCode,
-                                      Integer processInstanceId,
-                                      String processInstanceName,
-                                      String processDefinitionName,
+                                      Integer workflowInstanceId,
+                                      String workflowInstanceName,
+                                      String workflowDefinitionName,
                                       String taskName,
                                       Long taskCode,
                                       String executorName,
@@ -156,14 +142,14 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
         Date start = checkAndParseDateParameters(startDate);
         Date end = checkAndParseDateParameters(endDate);
         Page<TaskInstance> page = new Page<>(pageNo, pageSize);
-        PageInfo<Map<String, Object>> pageInfo = new PageInfo<>(pageNo, pageSize);
+        PageInfo<TaskInstance> pageInfo = new PageInfo<>(pageNo, pageSize);
         IPage<TaskInstance> taskInstanceIPage;
         if (taskExecuteType == TaskExecuteType.STREAM) {
-            // stream task without process instance
+            // stream task without workflow instance
             taskInstanceIPage = taskInstanceMapper.queryStreamTaskInstanceListPaging(
                     page,
                     projectCode,
-                    processDefinitionName,
+                    workflowDefinitionName,
                     searchVal,
                     taskName,
                     taskCode,
@@ -177,8 +163,8 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
             taskInstanceIPage = taskInstanceMapper.queryTaskInstanceListPaging(
                     page,
                     projectCode,
-                    processInstanceId,
-                    processInstanceName,
+                    workflowInstanceId,
+                    workflowInstanceName,
                     searchVal,
                     taskName,
                     taskCode,
@@ -189,9 +175,6 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
                     start,
                     end);
         }
-        Set<String> exclusionSet = new HashSet<>();
-        exclusionSet.add(Constants.CLASS);
-        exclusionSet.add("taskJson");
         List<TaskInstance> taskInstanceList = taskInstanceIPage.getRecords();
         List<Integer> executorIds =
                 taskInstanceList.stream().map(TaskInstance::getExecutorId).distinct().collect(Collectors.toList());
@@ -205,7 +188,7 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
             }
         }
         pageInfo.setTotal((int) taskInstanceIPage.getTotal());
-        pageInfo.setTotalList(CollectionUtils.getListByExclusion(taskInstanceIPage.getRecords(), exclusionSet));
+        pageInfo.setTotalList(taskInstanceList);
         result.setData(pageInfo);
         putMsg(result, Status.SUCCESS);
         return result;
@@ -232,11 +215,11 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
             throw new ServiceException("The task instance is not under the project: " + projectCode);
         }
 
-        ProcessInstance processInstance = workflowInstanceDao.queryOptionalById(task.getProcessInstanceId())
+        WorkflowInstance workflowInstance = workflowInstanceDao.queryOptionalById(task.getWorkflowInstanceId())
                 .orElseThrow(
-                        () -> new ServiceException(Status.PROCESS_INSTANCE_NOT_EXIST, task.getProcessInstanceId()));
-        if (!processInstance.getState().isFinished()) {
-            throw new ServiceException("The workflow instance is not finished: " + processInstance.getState()
+                        () -> new ServiceException(Status.WORKFLOW_INSTANCE_NOT_EXIST, task.getWorkflowInstanceId()));
+        if (!workflowInstance.getState().isFinished()) {
+            throw new ServiceException("The workflow instance is not finished: " + workflowInstance.getState()
                     + " cannot force start task instance");
         }
 
@@ -252,7 +235,7 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
         if (changedNum <= 0) {
             throw new ServiceException(Status.FORCE_TASK_SUCCESS_ERROR);
         }
-        processService.forceProcessInstanceSuccessByTaskInstanceId(task);
+        processService.forceWorkflowInstanceSuccessByTaskInstanceId(task);
         log.info("Force success task instance:{} success", taskInstanceId);
     }
 
@@ -277,11 +260,10 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
             putMsg(result, Status.TASK_INSTANCE_NOT_FOUND);
             return result;
         }
-        IStreamingTaskInstanceOperator streamingTaskInstanceOperator =
-                SingletonJdkDynamicRpcClientProxyFactory
-                        .getProxyClient(taskInstance.getHost(), IStreamingTaskInstanceOperator.class);
-        TaskInstanceTriggerSavepointResponse taskInstanceTriggerSavepointResponse =
-                streamingTaskInstanceOperator.triggerSavepoint(new TaskInstanceTriggerSavepointRequest(taskInstanceId));
+        final TaskInstanceTriggerSavepointResponse taskInstanceTriggerSavepointResponse = Clients
+                .withService(IStreamingTaskInstanceOperator.class)
+                .withHost(taskInstance.getHost())
+                .triggerSavepoint(new TaskInstanceTriggerSavepointRequest(taskInstanceId));
         log.info("StreamingTaskInstance trigger savepoint response: {}", taskInstanceTriggerSavepointResponse);
         putMsg(result, Status.SUCCESS);
         return result;
@@ -310,11 +292,11 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
         }
 
         // todo: we only support streaming task for now
-        ITaskInstanceOperator iTaskInstanceOperator = SingletonJdkDynamicRpcClientProxyFactory
-                .getProxyClient(taskInstance.getHost(), ITaskInstanceOperator.class);
-        TaskInstanceKillResponse taskInstanceKillResponse =
-                iTaskInstanceOperator.killTask(new TaskInstanceKillRequest(taskInstanceId));
-        log.info("TaskInstance kill response: {}", taskInstanceKillResponse);
+        final TaskExecutorKillResponse taskExecutorKillResponse = Clients
+                .withService(IPhysicalTaskExecutorOperator.class)
+                .withHost(taskInstance.getHost())
+                .killTask(TaskExecutorKillRequest.of(taskInstanceId));
+        log.info("TaskInstance kill response: {}", taskExecutorKillResponse);
 
         putMsg(result, Status.SUCCESS);
         return result;
@@ -333,31 +315,6 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
         return taskInstance;
     }
 
-    @Override
-    public TaskInstanceRemoveCacheResponse removeTaskInstanceCache(User loginUser, long projectCode,
-                                                                   Integer taskInstanceId) {
-        Result result = new Result();
-
-        Project project = projectMapper.queryByCode(projectCode);
-        projectService.checkProjectAndAuthThrowException(loginUser, project, INSTANCE_UPDATE);
-
-        TaskInstance taskInstance = taskInstanceMapper.selectById(taskInstanceId);
-        if (taskInstance == null) {
-            log.error("Task definition can not be found, projectCode:{}, taskInstanceId:{}.", projectCode,
-                    taskInstanceId);
-            putMsg(result, Status.TASK_INSTANCE_NOT_FOUND);
-            return new TaskInstanceRemoveCacheResponse(result);
-        }
-        String tagCacheKey = taskInstance.getCacheKey();
-        Pair<Integer, String> taskIdAndCacheKey = TaskCacheUtils.revertCacheKey(tagCacheKey);
-        String cacheKey = taskIdAndCacheKey.getRight();
-        if (StringUtils.isNotEmpty(cacheKey)) {
-            taskInstanceDao.clearCacheByCacheKey(cacheKey);
-        }
-        putMsg(result, Status.SUCCESS);
-        return new TaskInstanceRemoveCacheResponse(result, cacheKey);
-    }
-
     @Override
     public void deleteByWorkflowInstanceId(Integer workflowInstanceId) {
         List<TaskInstance> needToDeleteTaskInstances =
@@ -369,17 +326,16 @@ public class TaskInstanceServiceImpl extends BaseServiceImpl implements TaskInst
             if (StringUtils.isNotBlank(taskInstance.getLogPath())) {
                 try {
                     // Remove task instance log failed will not affect the deletion of task instance
-                    ILogService iLogService =
-                            SingletonJdkDynamicRpcClientProxyFactory.getProxyClient(taskInstance.getHost(),
-                                    ILogService.class);
-                    iLogService.removeTaskInstanceLog(taskInstance.getLogPath());
+                    Clients
+                            .withService(ILogService.class)
+                            .withHost(taskInstance.getHost())
+                            .removeTaskInstanceLog(taskInstance.getLogPath());
                 } catch (Exception ex) {
                     log.error("Remove task instance log error", ex);
                 }
             }
         }
 
-        dqExecuteResultDao.deleteByWorkflowInstanceId(workflowInstanceId);
         taskGroupQueueService.deleteByWorkflowInstanceId(workflowInstanceId);
         taskInstanceDao.deleteByWorkflowInstanceId(workflowInstanceId);
     }
