@@ -17,11 +17,21 @@
 
 package org.apache.dolphinscheduler.api.service;
 
+import static org.apache.dolphinscheduler.api.AssertionsHelper.assertDoesNotThrow;
+import static org.apache.dolphinscheduler.api.AssertionsHelper.assertThrowsServiceException;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.DOWNLOAD_LOG;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.VIEW_LOG;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doThrow;
+import static org.mockito.Mockito.when;
 
+import org.apache.dolphinscheduler.api.AssertionsHelper;
 import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.exceptions.ServiceException;
+import org.apache.dolphinscheduler.api.executor.logging.LogClientDelegate;
 import org.apache.dolphinscheduler.api.service.impl.LoggerServiceImpl;
 import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.common.constants.Constants;
@@ -33,7 +43,6 @@ import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.dolphinscheduler.dao.mapper.ProjectMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskDefinitionMapper;
 import org.apache.dolphinscheduler.dao.repository.TaskInstanceDao;
-import org.apache.dolphinscheduler.service.log.LogClient;
 
 import java.text.MessageFormat;
 import java.util.HashMap;
@@ -44,16 +53,12 @@ import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.ExtendWith;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
-import org.mockito.Mockito;
 import org.mockito.junit.jupiter.MockitoExtension;
 import org.mockito.junit.jupiter.MockitoSettings;
 import org.mockito.quality.Strictness;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-/**
- * logger service test
- */
 @ExtendWith(MockitoExtension.class)
 @MockitoSettings(strictness = Strictness.LENIENT)
 public class LoggerServiceTest {
@@ -76,7 +81,9 @@ public class LoggerServiceTest {
     private TaskDefinitionMapper taskDefinitionMapper;
 
     @Mock
-    private LogClient logClient;
+    private LogClientDelegate logClientDelegate;
+
+    private final int nettyServerPort = 18080;
 
     @Test
     public void testQueryLog() {
@@ -85,7 +92,7 @@ public class LoggerServiceTest {
         loginUser.setId(1);
         TaskInstance taskInstance = new TaskInstance();
         taskInstance.setExecutorId(loginUser.getId() + 1);
-        Mockito.when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
+        when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
         Result result = loggerService.queryLog(loginUser, 2, 1, 1);
         // TASK_INSTANCE_NOT_FOUND
         Assertions.assertEquals(Status.TASK_INSTANCE_NOT_FOUND.getCode(), result.getCode().intValue());
@@ -100,32 +107,32 @@ public class LoggerServiceTest {
         Assertions.assertEquals(Status.TASK_INSTANCE_HOST_IS_NULL.getCode(), result.getCode().intValue());
 
         // PROJECT_NOT_EXIST
-        taskInstance.setHost("127.0.0.1:8080");
+        taskInstance.setHost("127.0.0.1:" + nettyServerPort);
         taskInstance.setLogPath("/temp/log");
-        try {
-            Mockito.doThrow(new ServiceException(Status.PROJECT_NOT_EXIST)).when(projectService)
-                    .checkProjectAndAuthThrowException(loginUser, null, VIEW_LOG);
-            loggerService.queryLog(loginUser, 1, 1, 1);
-        } catch (ServiceException serviceException) {
-            Assertions.assertEquals(Status.PROJECT_NOT_EXIST.getCode(), serviceException.getCode());
-        }
+        doThrow(new ServiceException(Status.PROJECT_NOT_EXIST)).when(projectService)
+                .checkProjectAndAuthThrowException(loginUser, taskInstance.getProjectCode(), VIEW_LOG);
+        AssertionsHelper.assertThrowsServiceException(Status.PROJECT_NOT_EXIST,
+                () -> loggerService.queryLog(loginUser, 1, 1, 1));
 
         // USER_NO_OPERATION_PERM
-        Project project = getProject(1);
-        Mockito.when(projectMapper.queryProjectByTaskInstanceId(1)).thenReturn(project);
-        try {
-            Mockito.doThrow(new ServiceException(Status.USER_NO_OPERATION_PERM)).when(projectService)
-                    .checkProjectAndAuthThrowException(loginUser, project, VIEW_LOG);
-            loggerService.queryLog(loginUser, 1, 1, 1);
-        } catch (ServiceException serviceException) {
-            Assertions.assertEquals(Status.USER_NO_OPERATION_PERM.getCode(), serviceException.getCode());
-        }
+        doThrow(new ServiceException(Status.USER_NO_OPERATION_PERM)).when(projectService)
+                .checkProjectAndAuthThrowException(loginUser, taskInstance.getProjectCode(), VIEW_LOG);
+        AssertionsHelper.assertThrowsServiceException(Status.USER_NO_OPERATION_PERM,
+                () -> loggerService.queryLog(loginUser, 1, 1, 1));
 
         // SUCCESS
-        Mockito.doNothing().when(projectService).checkProjectAndAuthThrowException(loginUser, project, VIEW_LOG);
-        Mockito.when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
+        doNothing().when(projectService).checkProjectAndAuthThrowException(loginUser, taskInstance.getProjectCode(),
+                VIEW_LOG);
+        when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
         result = loggerService.queryLog(loginUser, 1, 1, 1);
         Assertions.assertEquals(Status.SUCCESS.getCode(), result.getCode().intValue());
+
+        result = loggerService.queryLog(loginUser, 1, 0, 1);
+        Assertions.assertEquals(Status.SUCCESS.getCode(), result.getCode().intValue());
+
+        taskInstance.setLogPath("");
+        assertThrowsServiceException(Status.QUERY_TASK_INSTANCE_LOG_ERROR,
+                () -> loggerService.queryLog(loginUser, 1, 1, 1));
     }
 
     @Test
@@ -134,8 +141,9 @@ public class LoggerServiceTest {
         User loginUser = new User();
         loginUser.setId(1);
         TaskInstance taskInstance = new TaskInstance();
+        taskInstance.setId(1);
         taskInstance.setExecutorId(loginUser.getId() + 1);
-        Mockito.when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
+        when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
 
         // task instance is null
         try {
@@ -156,69 +164,81 @@ public class LoggerServiceTest {
         }
 
         // PROJECT_NOT_EXIST
-        taskInstance.setHost("127.0.0.1:8080");
+        taskInstance.setHost("127.0.0.1:" + nettyServerPort);
         taskInstance.setLogPath("/temp/log");
-        try {
-            Mockito.doThrow(new ServiceException(Status.PROJECT_NOT_EXIST)).when(projectService)
-                    .checkProjectAndAuthThrowException(loginUser, null, DOWNLOAD_LOG);
-            loggerService.queryLog(loginUser, 1, 1, 1);
-        } catch (ServiceException serviceException) {
-            Assertions.assertEquals(Status.PROJECT_NOT_EXIST.getCode(), serviceException.getCode());
-        }
+        doThrow(new ServiceException(Status.PROJECT_NOT_EXIST)).when(projectService)
+                .checkProjectAndAuthThrowException(loginUser, taskInstance.getProjectCode(), VIEW_LOG);
+        AssertionsHelper.assertThrowsServiceException(Status.PROJECT_NOT_EXIST,
+                () -> loggerService.queryLog(loginUser, 1, 1, 1));
 
         // USER_NO_OPERATION_PERM
-        Project project = getProject(1);
-        Mockito.when(projectMapper.queryProjectByTaskInstanceId(1)).thenReturn(project);
-        try {
-            Mockito.doThrow(new ServiceException(Status.USER_NO_OPERATION_PERM)).when(projectService)
-                    .checkProjectAndAuthThrowException(loginUser, project, DOWNLOAD_LOG);
-            loggerService.queryLog(loginUser, 1, 1, 1);
-        } catch (ServiceException serviceException) {
-            Assertions.assertEquals(Status.USER_NO_OPERATION_PERM.getCode(), serviceException.getCode());
-        }
+        doThrow(new ServiceException(Status.USER_NO_OPERATION_PERM)).when(projectService)
+                .checkProjectAndAuthThrowException(loginUser, taskInstance.getProjectCode(), VIEW_LOG);
+        AssertionsHelper.assertThrowsServiceException(Status.USER_NO_OPERATION_PERM,
+                () -> loggerService.queryLog(loginUser, 1, 1, 1));
 
         // SUCCESS
-        Mockito.doNothing().when(projectService).checkProjectAndAuthThrowException(loginUser, project, DOWNLOAD_LOG);
-        Mockito.when(logClient.getLogBytes(Mockito.anyString(), Mockito.anyInt(), Mockito.anyString()))
-                .thenReturn(new byte[0]);
-        Mockito.when(projectMapper.queryProjectByTaskInstanceId(1)).thenReturn(project);
-        byte[] result = loggerService.getLogBytes(loginUser, 1);
-        Assertions.assertEquals(62, result.length);
+        when(logClientDelegate.getWholeLogBytes(any())).thenReturn(new byte[0]);
+        doNothing().when(projectService).checkProjectAndAuthThrowException(loginUser, taskInstance.getProjectCode(),
+                DOWNLOAD_LOG);
+        when(logClientDelegate.getWholeLogBytes(any())).thenReturn(new byte[0]);
+        byte[] logBytes = loggerService.getLogBytes(loginUser, 1);
+        Assertions.assertEquals(42, logBytes.length - String.valueOf(nettyServerPort).length());
     }
 
     @Test
     public void testQueryLogInSpecifiedProject() {
         long projectCode = 1L;
-        Mockito.when(projectMapper.queryByCode(projectCode)).thenReturn(getProject(projectCode));
-        Project project = getProject(projectCode);
 
         User loginUser = new User();
         loginUser.setId(-1);
         loginUser.setUserType(UserType.GENERAL_USER);
-        Map<String, Object> result = new HashMap<>();
-        putMsg(result, Status.SUCCESS, projectCode);
         TaskInstance taskInstance = new TaskInstance();
-        Mockito.when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
+        when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
+        when(taskInstanceDao.queryById(10)).thenReturn(null);
+
+        assertThrowsServiceException(Status.TASK_INSTANCE_NOT_FOUND,
+                () -> loggerService.queryLog(loginUser, projectCode, 10, 1, 1));
+
         TaskDefinition taskDefinition = new TaskDefinition();
         taskDefinition.setProjectCode(projectCode);
         taskDefinition.setCode(1L);
+
         // SUCCESS
         taskInstance.setTaskCode(1L);
         taskInstance.setId(1);
-        taskInstance.setHost("127.0.0.1:8080");
+        taskInstance.setHost("127.0.0.1:" + nettyServerPort);
         taskInstance.setLogPath("/temp/log");
-        Mockito.when(projectService.checkProjectAndAuth(loginUser, project, projectCode, VIEW_LOG)).thenReturn(result);
-        Mockito.when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
-        Mockito.when(taskDefinitionMapper.queryByCode(taskInstance.getTaskCode())).thenReturn(taskDefinition);
-        result = loggerService.queryLog(loginUser, projectCode, 1, 1, 1);
-        Assertions.assertEquals(Status.SUCCESS.getCode(), ((Status) result.get(Constants.STATUS)).getCode());
+        doNothing().when(projectService).checkProjectAndAuthThrowException(loginUser, projectCode, VIEW_LOG);
+        when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
+        when(taskDefinitionMapper.queryByCode(taskInstance.getTaskCode())).thenReturn(taskDefinition);
+        assertDoesNotThrow(() -> loggerService.queryLog(loginUser, projectCode, 1, 1, 1));
+
+        taskDefinition.setProjectCode(10);
+        assertThrowsServiceException(Status.TASK_INSTANCE_NOT_FOUND,
+                () -> loggerService.queryLog(loginUser, projectCode, 1, 1, 1));
+
+        taskDefinition.setProjectCode(1);
+        taskInstance.setId(10);
+        when(taskInstanceDao.queryById(10)).thenReturn(taskInstance);
+
+        when(logClientDelegate.getPartLogString(any(), anyInt(), anyInt())).thenReturn("log content");
+
+        String result = loggerService.queryLog(loginUser, projectCode, 10, 1, 1);
+        assertEquals("log content", result);
+
+        taskInstance.setId(100);
+        when(taskInstanceDao.queryById(100)).thenReturn(taskInstance);
+        doThrow(new ServiceException("query log error")).when(logClientDelegate).getPartLogString(any(), anyInt(),
+                anyInt());
+        assertThrowsServiceException(Status.QUERY_TASK_INSTANCE_LOG_ERROR,
+                () -> loggerService.queryLog(loginUser, projectCode, 10, 1, 1));
     }
 
     @Test
     public void testGetLogBytesInSpecifiedProject() {
         long projectCode = 1L;
-        Mockito.when(projectMapper.queryByCode(projectCode)).thenReturn(getProject(projectCode));
-        Project project = getProject(projectCode);
+        when(projectMapper.queryByCode(projectCode)).thenReturn(getProject(projectCode));
 
         User loginUser = new User();
         loginUser.setId(-1);
@@ -232,15 +252,29 @@ public class LoggerServiceTest {
         // SUCCESS
         taskInstance.setTaskCode(1L);
         taskInstance.setId(1);
-        taskInstance.setHost("127.0.0.1:8080");
+        taskInstance.setHost("127.0.0.1:" + nettyServerPort);
         taskInstance.setLogPath("/temp/log");
-        Mockito.when(projectService.checkProjectAndAuth(loginUser, project, projectCode, DOWNLOAD_LOG))
-                .thenReturn(result);
-        Mockito.when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
-        Mockito.when(taskDefinitionMapper.queryByCode(taskInstance.getTaskCode())).thenReturn(taskDefinition);
-        Mockito.when(logClient.getLogBytes(Mockito.anyString(), Mockito.anyInt(), Mockito.anyString()))
-                .thenReturn(new byte[0]);
-        loggerService.getLogBytes(loginUser, projectCode, 1);
+        doNothing().when(projectService).checkProjectAndAuthThrowException(loginUser, projectCode, DOWNLOAD_LOG);
+
+        when(taskInstanceDao.queryById(1)).thenReturn(null);
+        assertThrowsServiceException(
+                Status.INTERNAL_SERVER_ERROR_ARGS, () -> loggerService.getLogBytes(loginUser, projectCode, 1));
+
+        when(taskInstanceDao.queryById(1)).thenReturn(taskInstance);
+        when(taskDefinitionMapper.queryByCode(taskInstance.getTaskCode())).thenReturn(taskDefinition);
+        when(logClientDelegate.getWholeLogBytes(any())).thenReturn(new byte[0]);
+        assertDoesNotThrow(() -> loggerService.getLogBytes(loginUser, projectCode, 1));
+
+        taskDefinition.setProjectCode(2L);
+        assertThrowsServiceException(Status.INTERNAL_SERVER_ERROR_ARGS,
+                () -> loggerService.getLogBytes(loginUser, projectCode, 1));
+
+        taskDefinition.setProjectCode(1L);
+        taskInstance.setId(100);
+        when(taskInstanceDao.queryById(100)).thenReturn(taskInstance);
+        doThrow(new ServiceException("download error")).when(logClientDelegate).getWholeLogBytes(any());
+        assertThrowsServiceException(Status.DOWNLOAD_TASK_INSTANCE_LOG_FILE_ERROR,
+                () -> loggerService.getLogBytes(loginUser, projectCode, 100));
     }
 
     /**
