@@ -32,16 +32,17 @@ import org.apache.dolphinscheduler.api.service.impl.TenantServiceImpl;
 import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.UserType;
-import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
+import org.apache.dolphinscheduler.common.enums.WorkflowExecutionStatus;
 import org.apache.dolphinscheduler.dao.entity.Queue;
 import org.apache.dolphinscheduler.dao.entity.Schedule;
 import org.apache.dolphinscheduler.dao.entity.Tenant;
 import org.apache.dolphinscheduler.dao.entity.User;
-import org.apache.dolphinscheduler.dao.mapper.ProcessInstanceMapper;
+import org.apache.dolphinscheduler.dao.entity.WorkflowInstance;
 import org.apache.dolphinscheduler.dao.mapper.ScheduleMapper;
 import org.apache.dolphinscheduler.dao.mapper.TenantMapper;
 import org.apache.dolphinscheduler.dao.mapper.UserMapper;
-import org.apache.dolphinscheduler.plugin.storage.api.StorageOperate;
+import org.apache.dolphinscheduler.dao.mapper.WorkflowInstanceMapper;
+import org.apache.dolphinscheduler.plugin.storage.api.StorageOperator;
 
 import org.apache.commons.collections4.CollectionUtils;
 
@@ -86,7 +87,7 @@ public class TenantServiceTest {
     private ScheduleMapper scheduleMapper;
 
     @Mock
-    private ProcessInstanceMapper processInstanceMapper;
+    private WorkflowInstanceMapper workflowInstanceMapper;
 
     @Mock
     private UserMapper userMapper;
@@ -95,7 +96,7 @@ public class TenantServiceTest {
     private ResourcePermissionCheckService resourcePermissionCheckService;
 
     @Mock
-    private StorageOperate storageOperate;
+    private StorageOperator storageOperator;
 
     private static final String tenantCode = "hayden";
     private static final String tenantDesc = "This is the tenant desc";
@@ -190,8 +191,8 @@ public class TenantServiceTest {
         when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.TENANT, null, 0,
                 baseServiceLogger)).thenReturn(true);
         when(tenantMapper.queryById(1)).thenReturn(getTenant());
-        when(processInstanceMapper.queryByTenantCodeAndStatus(tenantCode,
-                org.apache.dolphinscheduler.service.utils.Constants.NOT_TERMINATED_STATES))
+        when(workflowInstanceMapper.queryByTenantCodeAndStatus(tenantCode,
+                WorkflowExecutionStatus.getNotTerminalStatus()))
                         .thenReturn(getInstanceList());
         when(scheduleMapper.queryScheduleListByTenant(tenantCode)).thenReturn(getScheduleList());
         when(userMapper.queryUserListByTenant(3)).thenReturn(getUserList());
@@ -204,7 +205,7 @@ public class TenantServiceTest {
                 () -> tenantService.deleteTenantById(getLoginUser(), 1));
 
         // DELETE_TENANT_BY_ID_FAIL_DEFINES
-        when(processInstanceMapper.queryByTenantCodeAndStatus(any(), any())).thenReturn(Collections.emptyList());
+        when(workflowInstanceMapper.queryByTenantCodeAndStatus(any(), any())).thenReturn(Collections.emptyList());
         when(tenantMapper.queryById(2)).thenReturn(getTenant(2));
         assertThrowsServiceException(Status.DELETE_TENANT_BY_ID_FAIL_DEFINES,
                 () -> tenantService.deleteTenantById(getLoginUser(), 2));
@@ -291,11 +292,11 @@ public class TenantServiceTest {
         return userList;
     }
 
-    private List<ProcessInstance> getInstanceList() {
-        List<ProcessInstance> processInstances = new ArrayList<>();
-        ProcessInstance processInstance = new ProcessInstance();
-        processInstances.add(processInstance);
-        return processInstances;
+    private List<WorkflowInstance> getInstanceList() {
+        List<WorkflowInstance> workflowInstances = new ArrayList<>();
+        WorkflowInstance workflowInstance = new WorkflowInstance();
+        workflowInstances.add(workflowInstance);
+        return workflowInstances;
     }
 
     private List<Schedule> getScheduleList() {
