@@ -20,15 +20,15 @@ package org.apache.dolphinscheduler.common.enums;
 import java.util.HashMap;
 import java.util.Map;
 
+import lombok.Getter;
 import lombok.NonNull;
 
 import com.baomidou.mybatisplus.annotation.EnumValue;
 
+@Getter
 public enum WorkflowExecutionStatus {
 
-    // This class is split from <code>ExecutionStatus</code> #11339.
-    // In order to compatible with the old value, the code is not consecutive
-    SUBMITTED_SUCCESS(0, "submit success"),
+    SUBMITTED_SUCCESS(0, "submitted"),
     RUNNING_EXECUTION(1, "running"),
     READY_PAUSE(2, "ready pause"),
     PAUSE(3, "pause"),
@@ -36,22 +36,24 @@ public enum WorkflowExecutionStatus {
     STOP(5, "stop"),
     FAILURE(6, "failure"),
     SUCCESS(7, "success"),
-    DELAY_EXECUTION(12, "delay execution"),
     SERIAL_WAIT(14, "serial wait"),
-    READY_BLOCK(15, "ready block"),
-    BLOCK(16, "block"),
-    WAIT_TO_RUN(17, "wait to run"),
-    ;
+    FAILOVER(18, "failover");
 
     private static final Map<Integer, WorkflowExecutionStatus> CODE_MAP = new HashMap<>();
     private static final int[] NEED_FAILOVER_STATES = new int[]{
-            SUBMITTED_SUCCESS.getCode(),
             RUNNING_EXECUTION.getCode(),
-            DELAY_EXECUTION.getCode(),
             READY_PAUSE.getCode(),
             READY_STOP.getCode()
     };
 
+    private static final int[] NOT_TERMINAL_STATUS = new int[]{
+            SUBMITTED_SUCCESS.getCode(),
+            RUNNING_EXECUTION.getCode(),
+            READY_PAUSE.getCode(),
+            READY_STOP.getCode(),
+            SERIAL_WAIT.getCode()
+    };
+
     static {
         for (WorkflowExecutionStatus executionStatus : WorkflowExecutionStatus.values()) {
             CODE_MAP.put(executionStatus.getCode(), executionStatus);
@@ -75,12 +77,43 @@ public enum WorkflowExecutionStatus {
     }
 
     public boolean canStop() {
-        return this == RUNNING_EXECUTION || this == READY_PAUSE;
+        return this == RUNNING_EXECUTION
+                || this == READY_PAUSE
+                || this == READY_STOP
+                || this == SERIAL_WAIT;
+    }
+
+    public boolean canDirectStopInDB() {
+        return this == SERIAL_WAIT;
+    }
+
+    public boolean canPause() {
+        return this == RUNNING_EXECUTION
+                || this == READY_PAUSE
+                || this == SERIAL_WAIT;
+    }
+
+    /**
+     * status can be take over on sub-workflow
+     * @return bool
+     */
+    public boolean canTakeover() {
+        return this == RUNNING_EXECUTION
+                || this == READY_PAUSE
+                || this == PAUSE
+                || this == READY_STOP
+                || this == STOP
+                || this == FAILURE
+                || this == SUCCESS
+                || this == FAILOVER;
+    }
+
+    public boolean canDirectPauseInDB() {
+        return this == SERIAL_WAIT;
     }
 
     public boolean isFinished() {
-        // todo: do we need to remove pause/block in finished judge?
-        return isSuccess() || isFailure() || isStop() || isPause() || isBlock();
+        return isSuccess() || isFailure() || isStop() || isPause();
     }
 
     /**
@@ -108,14 +141,14 @@ public enum WorkflowExecutionStatus {
         return this == STOP;
     }
 
-    public boolean isBlock() {
-        return this == BLOCK;
-    }
-
     public static int[] getNeedFailoverWorkflowInstanceState() {
         return NEED_FAILOVER_STATES;
     }
 
+    public static int[] getNotTerminalStatus() {
+        return NOT_TERMINAL_STATUS;
+    }
+
     @EnumValue
     private final int code;
 
@@ -126,16 +159,8 @@ public enum WorkflowExecutionStatus {
         this.desc = desc;
     }
 
-    public int getCode() {
-        return code;
-    }
-
-    public String getDesc() {
-        return desc;
-    }
-
     @Override
     public String toString() {
-        return "WorkflowExecutionStatus{" + "code=" + code + ", desc='" + desc + '\'' + '}';
+        return name();
     }
 }
