@@ -28,19 +28,19 @@ import java.util.TimeZone;
 
 import javax.management.timer.Timer;
 
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class DateUtilsTest {
 
-    @Before
+    @BeforeEach
     public void before() {
         ThreadLocalContext.getTimezoneThreadLocal().remove();
     }
 
-    @After
+    @AfterEach
     public void after() {
         ThreadLocalContext.getTimezoneThreadLocal().remove();
     }
@@ -57,7 +57,7 @@ public class DateUtilsTest {
 
         String readableDate = DateUtils.format2Readable(endDate.getTime() - startDate.getTime());
 
-        Assert.assertEquals("01 09:23:08", readableDate);
+        Assertions.assertEquals("01 09:23:08", readableDate);
     }
 
     @Test
@@ -68,67 +68,67 @@ public class DateUtilsTest {
         Date monday = DateUtils.getMonday(curr);
         Date sunday = DateUtils.getSunday(monday);
 
-        Assert.assertEquals(monday, monday1);
-        Assert.assertEquals(sunday, sunday1);
+        Assertions.assertEquals(monday, monday1);
+        Assertions.assertEquals(sunday, sunday1);
 
     }
 
     @Test
     public void dateToString() {
         Date d1 = DateUtils.stringToDate("2019-01-28");
-        Assert.assertNull(d1);
+        Assertions.assertNull(d1);
         d1 = DateUtils.stringToDate("2019-01-28 00:00:00");
-        Assert.assertEquals(DateUtils.dateToString(d1), "2019-01-28 00:00:00");
+        Assertions.assertEquals(DateUtils.dateToString(d1), "2019-01-28 00:00:00");
     }
 
     @Test
     public void getSomeDay() {
         Date d1 = DateUtils.stringToDate("2019-01-31 00:00:00");
         Date curr = DateUtils.getSomeDay(d1, 1);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-02-01 00:00:00");
-        Assert.assertEquals(DateUtils.dateToString(DateUtils.getSomeDay(d1, -31)), "2018-12-31 00:00:00");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-02-01 00:00:00");
+        Assertions.assertEquals(DateUtils.dateToString(DateUtils.getSomeDay(d1, -31)), "2018-12-31 00:00:00");
     }
 
     @Test
     public void getFirstDayOfMonth() {
         Date d1 = DateUtils.stringToDate("2019-01-31 00:00:00");
         Date curr = DateUtils.getFirstDayOfMonth(d1);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-01-01 00:00:00");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-01-01 00:00:00");
 
         d1 = DateUtils.stringToDate("2019-01-31 01:59:00");
         curr = DateUtils.getFirstDayOfMonth(d1);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-01-01 01:59:00");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-01-01 01:59:00");
     }
 
     @Test
     public void getSomeHourOfDay() {
         Date d1 = DateUtils.stringToDate("2019-01-31 11:59:59");
         Date curr = DateUtils.getSomeHourOfDay(d1, -1);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-01-31 10:00:00");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-01-31 10:00:00");
         curr = DateUtils.getSomeHourOfDay(d1, 0);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-01-31 11:00:00");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-01-31 11:00:00");
         curr = DateUtils.getSomeHourOfDay(d1, 2);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-01-31 13:00:00");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-01-31 13:00:00");
         curr = DateUtils.getSomeHourOfDay(d1, 24);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-02-01 11:00:00");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-02-01 11:00:00");
     }
 
     @Test
     public void getLastDayOfMonth() {
         Date d1 = DateUtils.stringToDate("2019-01-31 11:59:59");
         Date curr = DateUtils.getLastDayOfMonth(d1);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-01-31 11:59:59");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-01-31 11:59:59");
         d1 = DateUtils.stringToDate("2019-01-02 11:59:59");
         curr = DateUtils.getLastDayOfMonth(d1);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-01-31 11:59:59");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-01-31 11:59:59");
 
         d1 = DateUtils.stringToDate("2019-02-02 11:59:59");
         curr = DateUtils.getLastDayOfMonth(d1);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-02-28 11:59:59");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-02-28 11:59:59");
 
         d1 = DateUtils.stringToDate("2020-02-02 11:59:59");
         curr = DateUtils.getLastDayOfMonth(d1);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2020-02-29 11:59:59");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2020-02-29 11:59:59");
     }
 
     @Test
@@ -136,7 +136,7 @@ public class DateUtilsTest {
         Date d1 = DateUtils.stringToDate("2019-01-31 11:59:59");
         Date curr = DateUtils.getStartOfDay(d1);
         String expected = new SimpleDateFormat("yyyy-MM-dd").format(d1) + " 00:00:00";
-        Assert.assertEquals(DateUtils.dateToString(curr), expected);
+        Assertions.assertEquals(DateUtils.dateToString(curr), expected);
     }
 
     @Test
@@ -144,27 +144,27 @@ public class DateUtilsTest {
         Date d1 = DateUtils.stringToDate("2019-01-31 11:00:59");
         Date curr = DateUtils.getEndOfDay(d1);
         String expected = new SimpleDateFormat("yyyy-MM-dd").format(d1) + " 23:59:59";
-        Assert.assertEquals(DateUtils.dateToString(curr), expected);
+        Assertions.assertEquals(DateUtils.dateToString(curr), expected);
     }
 
     @Test
     public void getStartOfHour() {
         Date d1 = DateUtils.stringToDate("2019-01-31 11:00:59");
         Date curr = DateUtils.getStartOfHour(d1);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-01-31 11:00:00");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-01-31 11:00:00");
     }
 
     @Test
     public void getEndOfHour() {
         Date d1 = DateUtils.stringToDate("2019-01-31 11:00:59");
         Date curr = DateUtils.getEndOfHour(d1);
-        Assert.assertEquals(DateUtils.dateToString(curr), "2019-01-31 11:59:59");
+        Assertions.assertEquals(DateUtils.dateToString(curr), "2019-01-31 11:59:59");
     }
 
     @Test
     public void getCurrentTimeStamp() {
         String timeStamp = DateUtils.getCurrentTimeStamp();
-        Assert.assertNotNull(timeStamp);
+        Assertions.assertNotNull(timeStamp);
     }
 
     @Test
@@ -174,46 +174,49 @@ public class DateUtilsTest {
         Date start = DateUtils.stringToDate("2020-01-20 11:00:00");
         Date end = DateUtils.stringToDate("2020-01-21 12:10:10");
         String duration = DateUtils.format2Duration(start, end);
-        Assert.assertEquals("1d 1h 10m 10s", duration);
+        Assertions.assertEquals("1d 1h 10m 10s", duration);
+
+        duration = DateUtils.format2Duration(end, start);
+        Assertions.assertNull(duration);
 
         // hours minutes seconds
         start = DateUtils.stringToDate("2020-01-20 11:00:00");
         end = DateUtils.stringToDate("2020-01-20 12:10:10");
         duration = DateUtils.format2Duration(start, end);
-        Assert.assertEquals("1h 10m 10s", duration);
+        Assertions.assertEquals("1h 10m 10s", duration);
 
         // minutes seconds
         start = DateUtils.stringToDate("2020-01-20 11:00:00");
         end = DateUtils.stringToDate("2020-01-20 11:10:10");
         duration = DateUtils.format2Duration(start, end);
-        Assert.assertEquals("10m 10s", duration);
+        Assertions.assertEquals("10m 10s", duration);
 
         // minutes seconds
         start = DateUtils.stringToDate("2020-01-20 11:10:00");
         end = DateUtils.stringToDate("2020-01-20 11:10:10");
         duration = DateUtils.format2Duration(start, end);
-        Assert.assertEquals("10s", duration);
+        Assertions.assertEquals("10s", duration);
 
         start = DateUtils.stringToDate("2020-01-20 11:10:00");
         end = DateUtils.stringToDate("2020-01-21 11:10:10");
         duration = DateUtils.format2Duration(start, end);
-        Assert.assertEquals("1d 10s", duration);
+        Assertions.assertEquals("1d 10s", duration);
 
         start = DateUtils.stringToDate("2020-01-20 11:10:00");
         end = DateUtils.stringToDate("2020-01-20 16:10:10");
         duration = DateUtils.format2Duration(start, end);
-        Assert.assertEquals("5h 10s", duration);
+        Assertions.assertEquals("5h 10s", duration);
 
         // startTime = endTime, default 1s
         start = DateUtils.stringToDate("2020-01-20 11:10:00");
         end = DateUtils.stringToDate("2020-01-20 11:10:00");
         duration = DateUtils.format2Duration(start, end);
-        Assert.assertEquals("1s", duration);
+        Assertions.assertEquals("1s", duration);
 
         // endTime is null, use current time
         start = DateUtils.stringToDate("2020-01-20 11:10:00");
         duration = DateUtils.format2Duration(start, null);
-        Assert.assertNotNull(duration);
+        Assertions.assertNotNull(duration);
     }
 
     @Test
@@ -222,16 +225,17 @@ public class DateUtilsTest {
 
         Date date = new Date();
         Date defaultTimeZoneDate = DateUtils.transformTimezoneDate(date, TimeZone.getDefault().getID());
-        Assert.assertEquals(DateUtils.dateToString(date), DateUtils.dateToString(defaultTimeZoneDate));
+        Assertions.assertEquals(DateUtils.dateToString(date), DateUtils.dateToString(defaultTimeZoneDate));
 
         Date targetTimeZoneDate = DateUtils.transformTimezoneDate(date, TimeZone.getDefault().getID(), "Asia/Shanghai");
-        Assert.assertEquals(DateUtils.dateToString(date, TimeZone.getDefault().getID()), DateUtils.dateToString(targetTimeZoneDate, "Asia/Shanghai"));
+        Assertions.assertEquals(DateUtils.dateToString(date, TimeZone.getDefault().getID()),
+                DateUtils.dateToString(targetTimeZoneDate, "Asia/Shanghai"));
     }
 
     @Test
     public void testGetTimezone() {
-        Assert.assertNull(DateUtils.getTimezone(null));
-        Assert.assertEquals(TimeZone.getTimeZone("MST"), DateUtils.getTimezone("MST"));
+        Assertions.assertNull(DateUtils.getTimezone(null));
+        Assertions.assertEquals(TimeZone.getTimeZone("MST"), DateUtils.getTimezone("MST"));
     }
 
     @Test
@@ -240,13 +244,13 @@ public class DateUtilsTest {
         String time = "2019-01-28 00:00:00";
         ThreadLocalContext.timezoneThreadLocal.set("UTC");
         Date utcDate = DateUtils.stringToDate(time);
-        Assert.assertEquals(time, DateUtils.dateToString(utcDate));
+        Assertions.assertEquals(time, DateUtils.dateToString(utcDate));
 
         ThreadLocalContext.timezoneThreadLocal.set("Asia/Shanghai");
         Date shanghaiDate = DateUtils.stringToDate(time);
-        Assert.assertEquals(time, DateUtils.dateToString(shanghaiDate));
+        Assertions.assertEquals(time, DateUtils.dateToString(shanghaiDate));
 
-        Assert.assertEquals(Timer.ONE_HOUR * 8, utcDate.getTime() - shanghaiDate.getTime());
+        Assertions.assertEquals(Timer.ONE_HOUR * 8, utcDate.getTime() - shanghaiDate.getTime());
 
     }
 
@@ -258,6 +262,43 @@ public class DateUtilsTest {
         ZonedDateTime utcNow = asiaShNow.minusHours(8);
         String asiaShNowStr = DateUtils.dateToString(utcNow, asiaSh);
         String utcNowStr = DateUtils.dateToString(asiaShNow, utc);
-        Assert.assertEquals(asiaShNowStr, utcNowStr);
+        Assertions.assertEquals(asiaShNowStr, utcNowStr);
+    }
+
+    @Test
+    public void testDateToTimeStamp() throws ParseException {
+        // Beijing Date
+        String timeString = "2022-09-29 21:00:00";
+        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
+        sdf.setTimeZone(TimeZone.getTimeZone("Asia/Shanghai"));
+        Date date = sdf.parse(timeString);
+        long timeStamp = DateUtils.dateToTimeStamp(date);
+        Assertions.assertEquals(1664456400000L, timeStamp);
+
+        // Tokyo Date
+        String tokyoTime = "2022-09-29 22:00:00";
+        sdf.setTimeZone(TimeZone.getTimeZone("Asia/Tokyo"));
+        date = sdf.parse(tokyoTime);
+        timeStamp = DateUtils.dateToTimeStamp(date);
+        Assertions.assertEquals(1664456400000L, timeStamp);
+
+        date = null;
+        Assertions.assertEquals(0L, DateUtils.dateToTimeStamp(date));
+    }
+
+    @Test
+    public void testTimeStampToDate() {
+        long timeStamp = 1664456400000L;
+        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
+        sdf.setTimeZone(TimeZone.getTimeZone("Asia/Shanghai"));
+        String sd = sdf.format(new Date(timeStamp));
+        Assertions.assertEquals("2022-09-29 21:00:00", sd);
+
+        sdf.setTimeZone(TimeZone.getTimeZone("Asia/Tokyo"));
+        sd = sdf.format(new Date(timeStamp));
+        Assertions.assertEquals("2022-09-29 22:00:00", sd);
+
+        Date date = DateUtils.timeStampToDate(0L);
+        Assertions.assertNull(date);
     }
 }
