@@ -17,7 +17,6 @@
 
 package org.apache.dolphinscheduler.dao.entity;
 
-import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.Flag;
 import org.apache.dolphinscheduler.common.enums.Priority;
 import org.apache.dolphinscheduler.common.enums.TaskExecuteType;
@@ -34,7 +33,10 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 
+import lombok.AllArgsConstructor;
+import lombok.Builder;
 import lombok.Data;
+import lombok.NoArgsConstructor;
 
 import com.baomidou.mybatisplus.annotation.FieldStrategy;
 import com.baomidou.mybatisplus.annotation.IdType;
@@ -47,6 +49,9 @@ import com.fasterxml.jackson.databind.annotation.JsonSerialize;
 import com.google.common.base.Strings;
 
 @Data
+@Builder
+@NoArgsConstructor
+@AllArgsConstructor
 @TableName("t_ds_task_definition")
 public class TaskDefinition {
 
@@ -112,14 +117,10 @@ public class TaskDefinition {
 
     /**
      * task is valid: yes/no
+     * // todo: remove the flag field
      */
     private Flag flag;
 
-    /**
-     * task is cache: yes/no
-     */
-    private Flag isCache;
-
     /**
      * task priority
      */
@@ -224,9 +225,6 @@ public class TaskDefinition {
      */
     private TaskExecuteType taskExecuteType;
 
-    public TaskDefinition() {
-    }
-
     public TaskDefinition(long code, int version) {
         this.code = code;
         this.version = version;
@@ -260,10 +258,6 @@ public class TaskDefinition {
         return taskParamMap;
     }
 
-    public String getDependence() {
-        return JSONUtils.getNodeString(this.taskParams, Constants.DEPENDENCE);
-    }
-
     public Integer getCpuQuota() {
         return cpuQuota == null ? -1 : cpuQuota;
     }
@@ -287,7 +281,6 @@ public class TaskDefinition {
                 && Objects.equals(taskType, that.taskType)
                 && Objects.equals(taskParams, that.taskParams)
                 && flag == that.flag
-                && isCache == that.isCache
                 && taskPriority == that.taskPriority
                 && Objects.equals(workerGroup, that.workerGroup)
                 && timeoutFlag == that.timeoutFlag
