@@ -17,24 +17,15 @@
 
 package org.apache.dolphinscheduler.dao.mapper;
 
-import static org.apache.dolphinscheduler.common.constants.Constants.CACHE_KEY_VALUE_ALL;
-
+import org.apache.dolphinscheduler.common.enums.WorkerGroupSource;
 import org.apache.dolphinscheduler.dao.entity.WorkerGroup;
 
 import org.apache.ibatis.annotations.Param;
 
 import java.util.List;
 
-import org.springframework.cache.annotation.CacheConfig;
-import org.springframework.cache.annotation.CacheEvict;
-import org.springframework.cache.annotation.Cacheable;
-
 import com.baomidou.mybatisplus.core.mapper.BaseMapper;
 
-/**
- * worker group mapper interface
- */
-@CacheConfig(cacheNames = "workerGroup", keyGenerator = "cacheKeyGenerator")
 public interface WorkerGroupMapper extends BaseMapper<WorkerGroup> {
 
     /**
@@ -42,16 +33,12 @@ public interface WorkerGroupMapper extends BaseMapper<WorkerGroup> {
      *
      * @return worker group list
      */
-    @Cacheable(sync = true, key = CACHE_KEY_VALUE_ALL)
     List<WorkerGroup> queryAllWorkerGroup();
 
-    @CacheEvict(key = CACHE_KEY_VALUE_ALL)
     int deleteById(Integer id);
 
-    @CacheEvict(key = CACHE_KEY_VALUE_ALL)
     int insert(WorkerGroup entity);
 
-    @CacheEvict(key = CACHE_KEY_VALUE_ALL)
     int updateById(@Param("et") WorkerGroup entity);
 
     /**
@@ -62,4 +49,9 @@ public interface WorkerGroupMapper extends BaseMapper<WorkerGroup> {
      */
     List<WorkerGroup> queryWorkerGroupByName(@Param("name") String name);
 
+    int updateAddrListByWorkerGroupName(@Param("name") String name,
+                                        @Param("addrList") String addrList,
+                                        @Param("source") WorkerGroupSource source);
+
+    int deleteByWorkerGroupName(@Param("name") String name);
 }
