@@ -271,14 +271,21 @@ DROP TABLE IF EXISTS t_ds_alert CASCADE;
 CREATE TABLE t_ds_alert
 (
     id            int(11) NOT NULL AUTO_INCREMENT,
-    title         varchar(64) DEFAULT NULL,
+    title         varchar(512) DEFAULT NULL,
+    sign           char(40) NOT NULL DEFAULT '',
     content       text,
     alert_status  tinyint(4) DEFAULT '0',
+    warning_type  tinyint(4) DEFAULT '2',
     log           text,
     alertgroup_id int(11) DEFAULT NULL,
     create_time   datetime    DEFAULT NULL,
     update_time   datetime    DEFAULT NULL,
-    PRIMARY KEY (id)
+    project_code        bigint(20) DEFAULT NULL,
+    workflow_definition_code        bigint(20) DEFAULT NULL,
+    workflow_instance_id     int(11) DEFAULT NULL,
+    alert_type     int(11) DEFAULT NULL,
+    PRIMARY KEY (id),
+    KEY            idx_sign (sign)
 );
 
 -- ----------------------------
@@ -302,10 +309,6 @@ CREATE TABLE t_ds_alertgroup
     UNIQUE KEY t_ds_alertgroup_name_un (group_name)
 );
 
--- ----------------------------
--- Records of t_ds_alertgroup
--- ----------------------------
-
 -- ----------------------------
 -- Table structure for t_ds_command
 -- ----------------------------
@@ -314,7 +317,7 @@ CREATE TABLE t_ds_command
 (
     id                         int(11) NOT NULL AUTO_INCREMENT,
     command_type               tinyint(4) DEFAULT NULL,
-    process_definition_code    bigint(20) DEFAULT NULL,
+    workflow_definition_code    bigint(20) DEFAULT NULL,
     command_param              text,
     task_depend_type           tinyint(4) DEFAULT NULL,
     failure_strategy           tinyint(4) DEFAULT '0',
@@ -324,14 +327,15 @@ CREATE TABLE t_ds_command
     start_time                 datetime DEFAULT NULL,
     executor_id                int(11) DEFAULT NULL,
     update_time                datetime DEFAULT NULL,
-    process_instance_priority  int(11) DEFAULT NULL,
-    worker_group               varchar(64),
+    workflow_instance_priority  int(11) DEFAULT '2',
+    worker_group               varchar(255),
+    tenant_code                varchar(64) DEFAULT 'default',
     environment_code           bigint(20) DEFAULT '-1',
     dry_run                    int NULL DEFAULT 0,
-    process_instance_id        int(11) DEFAULT 0,
-    process_definition_version int(11) DEFAULT 0,
+    workflow_instance_id        int(11) DEFAULT 0,
+    workflow_definition_version int(11) DEFAULT 0,
     PRIMARY KEY (id),
-    KEY                        priority_id_index (process_instance_priority, id)
+    KEY                        priority_id_index (workflow_instance_priority, id)
 );
 
 -- ----------------------------
@@ -369,7 +373,7 @@ CREATE TABLE t_ds_error_command
     id                         int(11) NOT NULL,
     command_type               tinyint(4) DEFAULT NULL,
     executor_id                int(11) DEFAULT NULL,
-    process_definition_code    bigint(20) DEFAULT NULL,
+    workflow_definition_code    bigint(20) DEFAULT NULL,
     command_param              text,
     task_depend_type           tinyint(4) DEFAULT NULL,
     failure_strategy           tinyint(4) DEFAULT '0',
@@ -378,13 +382,14 @@ CREATE TABLE t_ds_error_command
     schedule_time              datetime DEFAULT NULL,
     start_time                 datetime DEFAULT NULL,
     update_time                datetime DEFAULT NULL,
-    process_instance_priority  int(11) DEFAULT NULL,
-    worker_group               varchar(64),
+    workflow_instance_priority  int(11) DEFAULT '2',
+    worker_group               varchar(255),
+    tenant_code                varchar(64) DEFAULT 'default',
     environment_code           bigint(20) DEFAULT '-1',
     message                    text,
     dry_run                    int NULL DEFAULT 0,
-    process_instance_id        int(11) DEFAULT 0,
-    process_definition_version int(11) DEFAULT 0,
+    workflow_instance_id        int(11) DEFAULT 0,
+    workflow_definition_version int(11) DEFAULT 0,
     PRIMARY KEY (id)
 );
 
@@ -393,15 +398,15 @@ CREATE TABLE t_ds_error_command
 -- ----------------------------
 
 -- ----------------------------
--- Table structure for t_ds_process_definition
+-- Table structure for t_ds_workflow_definition
 -- ----------------------------
-DROP TABLE IF EXISTS t_ds_process_definition CASCADE;
-CREATE TABLE t_ds_process_definition
+DROP TABLE IF EXISTS t_ds_workflow_definition CASCADE;
+CREATE TABLE t_ds_workflow_definition
 (
     id               int(11) NOT NULL AUTO_INCREMENT,
     code             bigint(20) NOT NULL,
     name             varchar(255) DEFAULT NULL,
-    version          int(11) DEFAULT NULL,
+    version          int(11) NOT NULL DEFAULT 1,
     description      text,
     project_code     bigint(20) NOT NULL,
     release_state    tinyint(4) DEFAULT NULL,
@@ -411,29 +416,24 @@ CREATE TABLE t_ds_process_definition
     locations        text,
     warning_group_id int(11) DEFAULT NULL,
     timeout          int(11) DEFAULT '0',
-    tenant_id        int(11) NOT NULL DEFAULT '-1',
     execution_type   tinyint(4) DEFAULT '0',
     create_time      datetime NOT NULL,
     update_time      datetime     DEFAULT NULL,
     PRIMARY KEY (id),
-    UNIQUE KEY process_unique (name,project_code) USING BTREE,
-    UNIQUE KEY code_unique (code)
+    UNIQUE KEY workflow_unique (name,project_code) USING BTREE,
+    UNIQUE KEY uniq_workflow_definition_code (code)
 );
 
 -- ----------------------------
--- Records of t_ds_process_definition
+-- Table structure for t_ds_workflow_definition_log
 -- ----------------------------
-
--- ----------------------------
--- Table structure for t_ds_process_definition_log
--- ----------------------------
-DROP TABLE IF EXISTS t_ds_process_definition_log CASCADE;
-CREATE TABLE t_ds_process_definition_log
+DROP TABLE IF EXISTS t_ds_workflow_definition_log CASCADE;
+CREATE TABLE t_ds_workflow_definition_log
 (
     id               int(11) NOT NULL AUTO_INCREMENT,
     code             bigint(20) NOT NULL,
-    name             varchar(200) DEFAULT NULL,
-    version          int(11) DEFAULT NULL,
+    name             varchar(255) DEFAULT NULL,
+    version          int(11) NOT NULL DEFAULT '1',
     description      text,
     project_code     bigint(20) NOT NULL,
     release_state    tinyint(4) DEFAULT NULL,
@@ -443,13 +443,13 @@ CREATE TABLE t_ds_process_definition_log
     locations        text,
     warning_group_id int(11) DEFAULT NULL,
     timeout          int(11) DEFAULT '0',
-    tenant_id        int(11) NOT NULL DEFAULT '-1',
     execution_type   tinyint(4) DEFAULT '0',
     operator         int(11) DEFAULT NULL,
     operate_time     datetime     DEFAULT NULL,
     create_time      datetime NOT NULL,
     update_time      datetime     DEFAULT NULL,
-    PRIMARY KEY (id)
+    PRIMARY KEY (id),
+    UNIQUE KEY uniq_idx_code_version (code, version) USING BTREE
 );
 
 -- ----------------------------
@@ -460,15 +460,16 @@ CREATE TABLE t_ds_task_definition
 (
     id                      int(11) NOT NULL AUTO_INCREMENT,
     code                    bigint(20) NOT NULL,
-    name                    varchar(200) DEFAULT NULL,
-    version                 int(11) DEFAULT NULL,
+    name                    varchar(255) DEFAULT NULL,
+    version                 int(11) NOT NULL DEFAULT '1',
     description             text,
     project_code            bigint(20) NOT NULL,
     user_id                 int(11) DEFAULT NULL,
     task_type               varchar(50) NOT NULL,
+    task_execute_type       int(11) DEFAULT '0',
     task_params             longtext,
     flag                    tinyint(2) DEFAULT NULL,
-    task_priority           tinyint(4) DEFAULT NULL,
+    task_priority           tinyint(4) DEFAULT '2',
     worker_group            varchar(200) DEFAULT NULL,
     environment_code        bigint(20) DEFAULT '-1',
     fail_retry_times        int(11) DEFAULT NULL,
@@ -477,6 +478,10 @@ CREATE TABLE t_ds_task_definition
     timeout_notify_strategy tinyint(4) DEFAULT NULL,
     timeout                 int(11) DEFAULT '0',
     delay_time              int(11) DEFAULT '0',
+    task_group_id           int(11) DEFAULT NULL,
+    task_group_priority     tinyint(4) DEFAULT '0',
+    cpu_quota               int(11) DEFAULT '-1' NOT NULL,
+    memory_max              int(11) DEFAULT '-1' NOT NULL,
     resource_ids            text,
     create_time             datetime    NOT NULL,
     update_time             datetime     DEFAULT NULL,
@@ -491,15 +496,16 @@ CREATE TABLE t_ds_task_definition_log
 (
     id                      int(11) NOT NULL AUTO_INCREMENT,
     code                    bigint(20) NOT NULL,
-    name                    varchar(200) DEFAULT NULL,
-    version                 int(11) DEFAULT NULL,
+    name                    varchar(255) DEFAULT NULL,
+    version                 int(11) NOT NULL DEFAULT '1',
     description             text,
     project_code            bigint(20) NOT NULL,
     user_id                 int(11) DEFAULT NULL,
     task_type               varchar(50) NOT NULL,
+    task_execute_type       int(11) DEFAULT '0',
     task_params             text,
     flag                    tinyint(2) DEFAULT NULL,
-    task_priority           tinyint(4) DEFAULT NULL,
+    task_priority           tinyint(4) DEFAULT '2',
     worker_group            varchar(200) DEFAULT NULL,
     environment_code        bigint(20) DEFAULT '-1',
     fail_retry_times        int(11) DEFAULT NULL,
@@ -510,6 +516,10 @@ CREATE TABLE t_ds_task_definition_log
     delay_time              int(11) DEFAULT '0',
     resource_ids            text,
     operator                int(11) DEFAULT NULL,
+    task_group_id           int(11) DEFAULT NULL,
+    task_group_priority     tinyint(4) DEFAULT '0',
+    cpu_quota               int(11) DEFAULT '-1' NOT NULL,
+    memory_max              int(11) DEFAULT '-1' NOT NULL,
     operate_time            datetime     DEFAULT NULL,
     create_time             datetime    NOT NULL,
     update_time             datetime     DEFAULT NULL,
@@ -517,16 +527,16 @@ CREATE TABLE t_ds_task_definition_log
 );
 
 -- ----------------------------
--- Table structure for t_ds_process_task_relation
+-- Table structure for t_ds_workflow_task_relation
 -- ----------------------------
-DROP TABLE IF EXISTS t_ds_process_task_relation CASCADE;
-CREATE TABLE t_ds_process_task_relation
+DROP TABLE IF EXISTS t_ds_workflow_task_relation CASCADE;
+CREATE TABLE t_ds_workflow_task_relation
 (
     id                         int(11) NOT NULL AUTO_INCREMENT,
-    name                       varchar(200) DEFAULT NULL,
-    process_definition_version int(11) DEFAULT NULL,
+    name                       varchar(255) DEFAULT NULL,
+    workflow_definition_version int(11) DEFAULT NULL,
     project_code               bigint(20) NOT NULL,
-    process_definition_code    bigint(20) NOT NULL,
+    workflow_definition_code    bigint(20) NOT NULL,
     pre_task_code              bigint(20) NOT NULL,
     pre_task_version           int(11) NOT NULL,
     post_task_code             bigint(20) NOT NULL,
@@ -539,16 +549,16 @@ CREATE TABLE t_ds_process_task_relation
 );
 
 -- ----------------------------
--- Table structure for t_ds_process_task_relation_log
+-- Table structure for t_ds_workflow_task_relation_log
 -- ----------------------------
-DROP TABLE IF EXISTS t_ds_process_task_relation_log CASCADE;
-CREATE TABLE t_ds_process_task_relation_log
+DROP TABLE IF EXISTS t_ds_workflow_task_relation_log CASCADE;
+CREATE TABLE t_ds_workflow_task_relation_log
 (
     id                         int(11) NOT NULL AUTO_INCREMENT,
-    name                       varchar(200) DEFAULT NULL,
-    process_definition_version int(11) DEFAULT NULL,
+    name                       varchar(255) DEFAULT NULL,
+    workflow_definition_version int(11) DEFAULT NULL,
     project_code               bigint(20) NOT NULL,
-    process_definition_code    bigint(20) NOT NULL,
+    workflow_definition_code    bigint(20) NOT NULL,
     pre_task_code              bigint(20) NOT NULL,
     pre_task_version           int(11) NOT NULL,
     post_task_code             bigint(20) NOT NULL,
@@ -563,16 +573,18 @@ CREATE TABLE t_ds_process_task_relation_log
 );
 
 -- ----------------------------
--- Table structure for t_ds_process_instance
+-- Table structure for t_ds_workflow_instance
 -- ----------------------------
-DROP TABLE IF EXISTS t_ds_process_instance CASCADE;
-CREATE TABLE t_ds_process_instance
+DROP TABLE IF EXISTS t_ds_workflow_instance CASCADE;
+CREATE TABLE t_ds_workflow_instance
 (
     id                         int(11) NOT NULL AUTO_INCREMENT,
     name                       varchar(255) DEFAULT NULL,
-    process_definition_version int(11) DEFAULT NULL,
-    process_definition_code    bigint(20) not NULL,
+    workflow_definition_version int(11) NOT NULL DEFAULT '1',
+    workflow_definition_code    bigint(20) not NULL,
+    project_code               bigint(20) DEFAULT NULL,
     state                      tinyint(4) DEFAULT NULL,
+    state_history              text,
     recovery                   tinyint(4) DEFAULT NULL,
     start_time                 datetime     DEFAULT NULL,
     end_time                   datetime     DEFAULT NULL,
@@ -590,25 +602,22 @@ CREATE TABLE t_ds_process_instance
     global_params              text,
     flag                       tinyint(4) DEFAULT '1',
     update_time                timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
-    is_sub_process             int(11) DEFAULT '0',
+    is_sub_workflow             int(11) DEFAULT '0',
     executor_id                int(11) NOT NULL,
+    executor_name              varchar(64) DEFAULT NULL,
     history_cmd                text,
-    process_instance_priority  int(11) DEFAULT NULL,
+    workflow_instance_priority  int(11) DEFAULT '2',
     worker_group               varchar(64)  DEFAULT NULL,
     environment_code           bigint(20) DEFAULT '-1',
     timeout                    int(11) DEFAULT '0',
-    next_process_instance_id   int(11) DEFAULT '0',
-    tenant_id                  int(11) NOT NULL DEFAULT '-1',
+    next_workflow_instance_id   int(11) DEFAULT '0',
+    tenant_code                varchar(64) DEFAULT 'default',
     var_pool                   longtext,
     dry_run                    int NULL DEFAULT 0,
     restart_time               datetime     DEFAULT NULL,
     PRIMARY KEY (id)
 );
 
--- ----------------------------
--- Records of t_ds_process_instance
--- ----------------------------
-
 -- ----------------------------
 -- Table structure for t_ds_project
 -- ----------------------------
@@ -616,20 +625,70 @@ DROP TABLE IF EXISTS t_ds_project CASCADE;
 CREATE TABLE t_ds_project
 (
     id          int(11) NOT NULL AUTO_INCREMENT,
-    name        varchar(100) DEFAULT NULL,
+    name        varchar(255) DEFAULT NULL,
     code        bigint(20) NOT NULL,
-    description varchar(200) DEFAULT NULL,
+    description varchar(255) DEFAULT NULL,
     user_id     int(11) DEFAULT NULL,
     flag        tinyint(4) DEFAULT '1',
     create_time datetime NOT NULL,
     update_time datetime     DEFAULT NULL,
-    PRIMARY KEY (id)
+    PRIMARY KEY (id),
+    UNIQUE KEY unique_name (name),
+    UNIQUE KEY unique_code (code)
 );
 
 -- ----------------------------
 -- Records of t_ds_project
 -- ----------------------------
 
+-- ----------------------------
+-- Table structure for t_ds_project_parameter
+-- ----------------------------
+DROP TABLE IF EXISTS t_ds_project_parameter CASCADE;
+CREATE TABLE t_ds_project_parameter
+(
+    id              int(11) NOT NULL AUTO_INCREMENT,
+    param_name      varchar(255) NOT NULL,
+    param_value     text NOT NULL,
+    param_data_type varchar(50) DEFAULT 'VARCHAR',
+    code            bigint(20) NOT NULL,
+    project_code    bigint(20) NOT NULL,
+    user_id         int(11) DEFAULT NULL,
+    operator        int(11) DEFAULT NULL,
+    create_time     datetime NOT NULL,
+    update_time     datetime     DEFAULT NULL,
+    PRIMARY KEY (id),
+    UNIQUE KEY unique_project_parameter_name (project_code, param_name),
+    UNIQUE KEY unique_project_parameter_code (code)
+);
+
+-- ----------------------------
+-- Records of t_ds_project_parameter
+-- ----------------------------
+
+-- ----------------------------
+-- Table structure for t_ds_project_preference
+-- ----------------------------
+DROP TABLE IF EXISTS t_ds_project_preference CASCADE;
+CREATE TABLE t_ds_project_preference
+(
+    id              int(11) NOT NULL AUTO_INCREMENT,
+    code            bigint(20) NOT NULL,
+    project_code    bigint(20) NOT NULL,
+    preferences     varchar(512) NOT NULL,
+    user_id         int(11) DEFAULT NULL,
+    state           int(11) DEFAULT '1',
+    create_time     datetime NOT NULL,
+    update_time     datetime     DEFAULT NULL,
+    PRIMARY KEY (id),
+    UNIQUE KEY unique_project_preference_project_code (project_code),
+    UNIQUE KEY unique_project_preference_code (code)
+);
+
+-- ----------------------------
+-- Records of t_ds_project_preference
+-- ----------------------------
+
 -- ----------------------------
 -- Table structure for t_ds_queue
 -- ----------------------------
@@ -641,7 +700,8 @@ CREATE TABLE t_ds_queue
     queue       varchar(64) DEFAULT NULL,
     create_time datetime    DEFAULT NULL,
     update_time datetime    DEFAULT NULL,
-    PRIMARY KEY (id)
+    PRIMARY KEY (id),
+    UNIQUE KEY unique_queue_name (queue_name)
 );
 
 -- ----------------------------
@@ -670,22 +730,18 @@ CREATE TABLE t_ds_relation_datasource_user
 -- ----------------------------
 
 -- ----------------------------
--- Table structure for t_ds_relation_process_instance
+-- Table structure for t_ds_relation_workflow_instance
 -- ----------------------------
-DROP TABLE IF EXISTS t_ds_relation_process_instance CASCADE;
-CREATE TABLE t_ds_relation_process_instance
+DROP TABLE IF EXISTS t_ds_relation_workflow_instance CASCADE;
+CREATE TABLE t_ds_relation_workflow_instance
 (
     id                         int(11) NOT NULL AUTO_INCREMENT,
-    parent_process_instance_id int(11) DEFAULT NULL,
+    parent_workflow_instance_id int(11) DEFAULT NULL,
     parent_task_instance_id    int(11) DEFAULT NULL,
-    process_instance_id        int(11) DEFAULT NULL,
+    workflow_instance_id        int(11) DEFAULT NULL,
     PRIMARY KEY (id)
 );
 
--- ----------------------------
--- Records of t_ds_relation_process_instance
--- ----------------------------
-
 -- ----------------------------
 -- Table structure for t_ds_relation_project_user
 -- ----------------------------
@@ -698,7 +754,8 @@ CREATE TABLE t_ds_relation_project_user
     perm        int(11) DEFAULT '1',
     create_time datetime DEFAULT NULL,
     update_time datetime DEFAULT NULL,
-    PRIMARY KEY (id)
+    PRIMARY KEY (id),
+    UNIQUE KEY uniq_uid_pid(user_id,project_id)
 );
 
 -- ----------------------------
@@ -708,6 +765,7 @@ CREATE TABLE t_ds_relation_project_user
 -- ----------------------------
 -- Table structure for t_ds_relation_resources_user
 -- ----------------------------
+-- Deprecated
 DROP TABLE IF EXISTS t_ds_relation_resources_user CASCADE;
 CREATE TABLE t_ds_relation_resources_user
 (
@@ -742,6 +800,7 @@ CREATE TABLE t_ds_relation_udfs_user
 -- ----------------------------
 -- Table structure for t_ds_resources
 -- ----------------------------
+-- Deprecated
 DROP TABLE IF EXISTS t_ds_resources CASCADE;
 CREATE TABLE t_ds_resources
 (
@@ -772,7 +831,7 @@ DROP TABLE IF EXISTS t_ds_schedules CASCADE;
 CREATE TABLE t_ds_schedules
 (
     id                        int(11) NOT NULL AUTO_INCREMENT,
-    process_definition_code   bigint(20) NOT NULL,
+    workflow_definition_code   bigint(20) NOT NULL,
     start_time                datetime     NOT NULL,
     end_time                  datetime     NOT NULL,
     timezone_id               varchar(40) DEFAULT NULL,
@@ -782,8 +841,9 @@ CREATE TABLE t_ds_schedules
     release_state             tinyint(4) NOT NULL,
     warning_type              tinyint(4) NOT NULL,
     warning_group_id          int(11) DEFAULT NULL,
-    process_instance_priority int(11) DEFAULT NULL,
-    worker_group              varchar(64) DEFAULT '',
+    workflow_instance_priority int(11) DEFAULT '2',
+    worker_group              varchar(255) DEFAULT '',
+    tenant_code                varchar(64) DEFAULT 'default',
     environment_code          bigint(20) DEFAULT '-1',
     create_time               datetime     NOT NULL,
     update_time               datetime     NOT NULL,
@@ -820,41 +880,61 @@ CREATE TABLE t_ds_task_instance
     id                      int(11) NOT NULL AUTO_INCREMENT,
     name                    varchar(255) DEFAULT NULL,
     task_type               varchar(50) NOT NULL,
+    task_execute_type       int(11) DEFAULT '0',
     task_code               bigint(20) NOT NULL,
-    task_definition_version int(11) DEFAULT NULL,
-    process_instance_id     int(11) DEFAULT NULL,
+    task_definition_version int(11) NOT NULL DEFAULT '1',
+    workflow_instance_id     int(11) DEFAULT NULL,
+    workflow_instance_name   varchar(255) DEFAULT NULL,
+    project_code            bigint(20) DEFAULT NULL,
     state                   tinyint(4) DEFAULT NULL,
     submit_time             datetime     DEFAULT NULL,
     start_time              datetime     DEFAULT NULL,
     end_time                datetime     DEFAULT NULL,
     host                    varchar(135) DEFAULT NULL,
     execute_path            varchar(200) DEFAULT NULL,
-    log_path                varchar(200) DEFAULT NULL,
+    log_path                longtext DEFAULT NULL,
     alert_flag              tinyint(4) DEFAULT NULL,
     retry_times             int(4) DEFAULT '0',
     pid                     int(4) DEFAULT NULL,
     app_link                text,
-    task_params             text,
+    task_params             longtext,
     flag                    tinyint(4) DEFAULT '1',
     retry_interval          int(4) DEFAULT NULL,
     max_retry_times         int(2) DEFAULT NULL,
     task_instance_priority  int(11) DEFAULT NULL,
-    worker_group            varchar(64)  DEFAULT NULL,
+    worker_group            varchar(255)  DEFAULT NULL,
     environment_code        bigint(20) DEFAULT '-1',
     environment_config      text         DEFAULT '',
     executor_id             int(11) DEFAULT NULL,
+    executor_name           varchar(64) DEFAULT NULL,
     first_submit_time       datetime     DEFAULT NULL,
     delay_time              int(4) DEFAULT '0',
+    task_group_id           int(11) DEFAULT NULL,
     var_pool                longtext,
     dry_run                 int NULL DEFAULT 0,
-    PRIMARY KEY (id),
-    FOREIGN KEY (process_instance_id) REFERENCES t_ds_process_instance (id) ON DELETE CASCADE
+    cpu_quota               int(11) DEFAULT '-1' NOT NULL,
+    memory_max              int(11) DEFAULT '-1' NOT NULL,
+    PRIMARY KEY (id)
 );
 
 -- ----------------------------
 -- Records of t_ds_task_instance
 -- ----------------------------
 
+-- ----------------------------
+-- Table structure for t_ds_task_instance_context
+-- ----------------------------
+DROP TABLE IF EXISTS `t_ds_task_instance_context`;
+CREATE TABLE `t_ds_task_instance_context` (
+    `id` int(11) NOT NULL AUTO_INCREMENT,
+    `task_instance_id` int(11) NOT NULL,
+    `context` text NOT NULL,
+    `context_type` varchar(200) NOT NULL,
+    `create_time` datetime NOT NULL,
+    `update_time` datetime NOT NULL,
+    PRIMARY KEY (`id`)
+);
+
 -- ----------------------------
 -- Table structure for t_ds_tenant
 -- ----------------------------
@@ -864,15 +944,18 @@ CREATE TABLE t_ds_tenant
     id          int(11) NOT NULL AUTO_INCREMENT,
     tenant_code varchar(64)  DEFAULT NULL,
     description varchar(255) DEFAULT NULL,
-    queue_id    int(11) DEFAULT NULL,
+    queue_id    int(11)      DEFAULT NULL,
     create_time datetime     DEFAULT NULL,
     update_time datetime     DEFAULT NULL,
-    PRIMARY KEY (id)
+    PRIMARY KEY (id),
+    UNIQUE KEY unique_tenant_code (tenant_code)
 );
 
 -- ----------------------------
 -- Records of t_ds_tenant
 -- ----------------------------
+INSERT IGNORE INTO `t_ds_tenant`
+VALUES ('-1', 'default', 'default tenant', '1', current_timestamp, current_timestamp);
 
 -- ----------------------------
 -- Table structure for t_ds_udfs
@@ -880,19 +963,20 @@ CREATE TABLE t_ds_tenant
 DROP TABLE IF EXISTS t_ds_udfs CASCADE;
 CREATE TABLE t_ds_udfs
 (
-    id            int(11) NOT NULL AUTO_INCREMENT,
-    user_id       int(11) NOT NULL,
+    id            int(11)      NOT NULL AUTO_INCREMENT,
+    user_id       int(11)      NOT NULL,
     func_name     varchar(100) NOT NULL,
     class_name    varchar(255) NOT NULL,
-    type          tinyint(4) NOT NULL,
+    type          tinyint(4)   NOT NULL,
     arg_types     varchar(255) DEFAULT NULL,
     database      varchar(255) DEFAULT NULL,
     description   varchar(255) DEFAULT NULL,
-    resource_id   int(11) NOT NULL,
+    resource_id   int(11)      NOT NULL,
     resource_name varchar(255) NOT NULL,
     create_time   datetime     NOT NULL,
     update_time   datetime     NOT NULL,
-    PRIMARY KEY (id)
+    PRIMARY KEY (id),
+    UNIQUE KEY unique_func_name (func_name)
 );
 
 -- ----------------------------
@@ -911,11 +995,12 @@ CREATE TABLE t_ds_user
     user_type     tinyint(4) DEFAULT NULL,
     email         varchar(64) DEFAULT NULL,
     phone         varchar(11) DEFAULT NULL,
-    tenant_id     int(11) DEFAULT NULL,
+    tenant_id     int(11) DEFAULT -1,
     create_time   datetime    DEFAULT NULL,
     update_time   datetime    DEFAULT NULL,
     queue         varchar(64) DEFAULT NULL,
     state         int(1) DEFAULT 1,
+    time_zone     varchar(32) DEFAULT NULL,
     PRIMARY KEY (id),
     UNIQUE KEY user_name_unique (user_name)
 );
@@ -935,6 +1020,7 @@ CREATE TABLE t_ds_worker_group
     addr_list   text NULL DEFAULT NULL,
     create_time datetime NULL DEFAULT NULL,
     update_time datetime NULL DEFAULT NULL,
+    description text NULL DEFAULT NULL,
     PRIMARY KEY (id),
     UNIQUE KEY name_unique (name)
 );
@@ -943,6 +1029,21 @@ CREATE TABLE t_ds_worker_group
 -- Records of t_ds_worker_group
 -- ----------------------------
 
+-- ----------------------------
+-- Table structure for t_ds_relation_project_worker_group
+-- ----------------------------
+DROP TABLE IF EXISTS t_ds_relation_project_worker_group CASCADE;
+CREATE TABLE t_ds_relation_project_worker_group
+(
+    id            int(11) NOT NULL AUTO_INCREMENT,
+    project_code  bigint(20) NOT NULL,
+    worker_group  varchar(255) DEFAULT NULL,
+    create_time   datetime DEFAULT NULL,
+    update_time   datetime DEFAULT NULL,
+    PRIMARY KEY (id),
+    UNIQUE KEY unique_project_worker_group(project_code,worker_group)
+);
+
 -- ----------------------------
 -- Table structure for t_ds_version
 -- ----------------------------
@@ -950,7 +1051,7 @@ DROP TABLE IF EXISTS t_ds_version CASCADE;
 CREATE TABLE t_ds_version
 (
     id      int(11) NOT NULL AUTO_INCREMENT,
-    version varchar(200) NOT NULL,
+    version varchar(63) NOT NULL,
     PRIMARY KEY (id),
     UNIQUE KEY version_UNIQUE (version)
 );
@@ -959,22 +1060,22 @@ CREATE TABLE t_ds_version
 -- Records of t_ds_version
 -- ----------------------------
 INSERT INTO t_ds_version
-VALUES ('1', '2.0.6');
+VALUES ('1', '3.3.1');
 
 
 -- ----------------------------
 -- Records of t_ds_alertgroup
 -- ----------------------------
 INSERT INTO t_ds_alertgroup(alert_instance_ids, create_user_id, group_name, description, create_time, update_time)
-VALUES ('1,2', 1, 'default admin warning group', 'default admin warning group', '2018-11-29 10:20:39',
+VALUES (NULL, 1, 'default admin warning group', 'default admin warning group', '2018-11-29 10:20:39',
         '2018-11-29 10:20:39');
 
 -- ----------------------------
 -- Records of t_ds_user
 -- ----------------------------
 INSERT INTO t_ds_user
-VALUES ('1', 'admin', '7ad2410b2f4c074479a8937a28a22b8f', '0', 'xxx@qq.com', '', '0', '2018-03-27 15:48:50',
-        '2018-10-24 17:40:22', null, 1);
+VALUES ('1', 'admin', '7ad2410b2f4c074479a8937a28a22b8f', '0', 'xxx@qq.com', '', '-1', '2018-03-27 15:48:50',
+        '2018-10-24 17:40:22', null, 1, null);
 
 -- ----------------------------
 -- Table structure for t_ds_plugin_define
@@ -983,7 +1084,7 @@ DROP TABLE IF EXISTS t_ds_plugin_define CASCADE;
 CREATE TABLE t_ds_plugin_define
 (
     id            int          NOT NULL AUTO_INCREMENT,
-    plugin_name   varchar(100) NOT NULL,
+    plugin_name   varchar(255) NOT NULL,
     plugin_type   varchar(100) NOT NULL,
     plugin_params text,
     create_time   timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP,
@@ -1007,6 +1108,7 @@ CREATE TABLE t_ds_alert_plugin_instance
     PRIMARY KEY (id)
 );
 
+
 --
 -- Table structure for table t_ds_environment
 --
@@ -1015,7 +1117,7 @@ CREATE TABLE t_ds_environment
 (
     id          int       NOT NULL AUTO_INCREMENT,
     code        bigint(20) NOT NULL,
-    name        varchar(100)       DEFAULT NULL,
+    name        varchar(255)       DEFAULT NULL,
     config      text               DEFAULT NULL,
     description text,
     operator    int                DEFAULT NULL,
@@ -1041,3 +1143,258 @@ CREATE TABLE t_ds_environment_worker_group_relation
     PRIMARY KEY (id),
     UNIQUE KEY environment_worker_group_unique (environment_code,worker_group)
 );
+
+DROP TABLE IF EXISTS t_ds_task_group_queue;
+CREATE TABLE t_ds_task_group_queue
+(
+   id           int(11) NOT NULL AUTO_INCREMENT ,
+   task_id      int(11) DEFAULT NULL ,
+   task_name    VARCHAR(255) DEFAULT NULL ,
+   group_id     int(11) DEFAULT NULL ,
+   workflow_instance_id   int(11) DEFAULT NULL ,
+   priority     int(8) DEFAULT '0' ,
+   status       int(4) DEFAULT '-1' ,
+   force_start  int(4) DEFAULT '0' ,
+   in_queue     int(4) DEFAULT '0' ,
+   create_time  datetime DEFAULT NULL ,
+   update_time  datetime DEFAULT NULL ,
+   KEY idx_t_ds_task_group_queue_in_queue (in_queue) ,
+   PRIMARY KEY (id)
+);
+
+DROP TABLE IF EXISTS t_ds_task_group;
+CREATE TABLE t_ds_task_group
+(
+   id          int(11)  NOT NULL AUTO_INCREMENT ,
+   name        varchar(255) DEFAULT NULL ,
+   description varchar(255) DEFAULT NULL ,
+   group_size  int(11) NOT NULL ,
+   project_code  bigint(20) DEFAULT '0',
+   use_size    int(11) DEFAULT '0' ,
+   user_id     int(11) DEFAULT NULL ,
+   status      int(4) DEFAULT '1'  ,
+   create_time datetime DEFAULT NULL ,
+   update_time datetime DEFAULT NULL ,
+   PRIMARY KEY(id)
+);
+
+-- ----------------------------
+-- Table structure for t_ds_audit_log
+-- ----------------------------
+DROP TABLE IF EXISTS t_ds_audit_log;
+CREATE TABLE t_ds_audit_log
+(
+    id                  int(11) NOT NULL AUTO_INCREMENT,
+    user_id             int(11) NOT NULL,
+    model_id            bigint(20) NOT NULL,
+    model_name          varchar(255) NOT NULL,
+    model_type          varchar(255) NOT NULL,
+    operation_type      varchar(255) NOT NULL,
+    description         varchar(255) NOT NULL,
+    latency             int(11) NOT NULL,
+    detail              varchar(255) DEFAULT NULL,
+    create_time         timestamp NULL DEFAULT CURRENT_TIMESTAMP,
+    PRIMARY KEY (id)
+);
+
+
+DROP TABLE IF EXISTS t_ds_k8s;
+CREATE TABLE t_ds_k8s
+(
+    id           int(11) NOT NULL AUTO_INCREMENT ,
+    k8s_name     varchar(255) DEFAULT NULL ,
+    k8s_config   text DEFAULT NULL,
+    create_time  datetime DEFAULT NULL ,
+    update_time  datetime DEFAULT NULL ,
+    PRIMARY KEY (id)
+);
+
+DROP TABLE IF EXISTS t_ds_k8s_namespace;
+CREATE TABLE t_ds_k8s_namespace (
+    id                 int(11) NOT NULL AUTO_INCREMENT ,
+    code               bigint(20) NOT NULL,
+    namespace          varchar(255) DEFAULT NULL,
+    user_id            int(11) DEFAULT NULL,
+    cluster_code       bigint(20) NOT NULL,
+    create_time        datetime DEFAULT NULL ,
+    update_time        datetime DEFAULT NULL ,
+    PRIMARY KEY (id) ,
+    UNIQUE KEY k8s_namespace_unique (namespace,cluster_code)
+);
+-- ----------------------------
+-- Records of t_ds_k8s_namespace
+-- ----------------------------
+INSERT INTO `t_ds_k8s_namespace`
+(`id`,`code`,`namespace`,`user_id`,`cluster_code`,`create_time`,`update_time`)
+VALUES (1, 990001, 'flink_test', 1, 0, '2022-03-03 11:31:24.0', '2022-03-03 11:31:24.0');
+
+INSERT INTO `t_ds_k8s_namespace`
+(`id`,`code`,`namespace`,`user_id`,`cluster_code`,`create_time`,`update_time`)
+VALUES (2, 990002, 'spark_test', 2, 0, '2021-03-03 11:31:24.0', '2021-03-03 11:31:24.0');
+
+INSERT INTO `t_ds_k8s_namespace`
+(`id`,`code`,`namespace`,`user_id`,`cluster_code`,`create_time`,`update_time`)
+VALUES (3, 990003, 'auth_test', 3, 0, '2020-03-03 11:31:24.0', '2020-03-03 11:31:24.0');
+
+-- ----------------------------
+-- Table structure for t_ds_relation_namespace_user
+-- ----------------------------
+DROP TABLE IF EXISTS t_ds_relation_namespace_user;
+CREATE TABLE t_ds_relation_namespace_user (
+    id                int(11) NOT NULL AUTO_INCREMENT ,
+    user_id           int(11) NOT NULL ,
+    namespace_id      int(11) NOT NULL ,
+    perm              int(11) DEFAULT '1' ,
+    create_time       datetime DEFAULT NULL ,
+    update_time       datetime DEFAULT NULL ,
+    PRIMARY KEY (id) ,
+    UNIQUE KEY namespace_user_unique (user_id,namespace_id)
+);
+
+-- ----------------------------
+-- Table structure for t_ds_alert_send_status
+-- ----------------------------
+DROP TABLE IF EXISTS t_ds_alert_send_status CASCADE;
+CREATE TABLE t_ds_alert_send_status
+(
+    id                            int NOT NULL AUTO_INCREMENT,
+    alert_id                      int NOT NULL,
+    alert_plugin_instance_id      int NOT NULL,
+    send_status                   tinyint(4) DEFAULT '0',
+    log                           text,
+    create_time                   timestamp NULL DEFAULT CURRENT_TIMESTAMP,
+    PRIMARY KEY (id),
+    UNIQUE KEY alert_send_status_unique (alert_id,alert_plugin_instance_id)
+);
+
+
+--
+-- Table structure for table t_ds_cluster
+--
+DROP TABLE IF EXISTS t_ds_cluster CASCADE;
+CREATE TABLE t_ds_cluster
+(
+    id          int       NOT NULL AUTO_INCREMENT,
+    code        bigint(20) NOT NULL,
+    name        varchar(255)       DEFAULT NULL,
+    config      text               DEFAULT NULL,
+    description text,
+    operator    int                DEFAULT NULL,
+    create_time timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
+    update_time timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+    PRIMARY KEY (id),
+    UNIQUE KEY cluster_name_unique (name),
+    UNIQUE KEY cluster_code_unique (code)
+);
+
+INSERT INTO `t_ds_cluster`
+(`id`, `code`, `name`, `config`, `description`, `operator`, `create_time`, `update_time`)
+VALUES (100, 0, 'ds_null_k8s', '{"k8s":"ds_null_k8s"}', 'test', 1, '2021-03-03 11:31:24.0', '2021-03-03 11:31:24.0');
+
+--
+-- Table structure for t_ds_fav_task
+--
+DROP TABLE IF EXISTS t_ds_fav_task CASCADE;
+CREATE TABLE t_ds_fav_task
+(
+    id        bigint(20) NOT NULL AUTO_INCREMENT,
+    task_type varchar(64) NOT NULL,
+    user_id   int         NOT NULL,
+    PRIMARY KEY (id)
+);
+
+
+DROP TABLE IF EXISTS t_ds_relation_sub_workflow;
+CREATE TABLE t_ds_relation_sub_workflow (
+    id BIGINT AUTO_INCREMENT NOT NULL,
+    parent_workflow_instance_id BIGINT NOT NULL,
+    parent_task_code BIGINT NOT NULL,
+    sub_workflow_instance_id BIGINT NOT NULL,
+    PRIMARY KEY (id),
+    INDEX idx_parent_workflow_instance_id (parent_workflow_instance_id),
+    INDEX idx_parent_task_code (parent_task_code),
+    INDEX idx_sub_workflow_instance_id (sub_workflow_instance_id)
+) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;
+
+-- ----------------------------
+-- Table structure for t_ds_workflow_task_lineage
+-- ----------------------------
+DROP TABLE IF EXISTS t_ds_workflow_task_lineage;
+CREATE TABLE t_ds_workflow_task_lineage
+(
+    `id`                           int      NOT NULL AUTO_INCREMENT,
+    `workflow_definition_code`      bigint(20)   NOT NULL DEFAULT 0,
+    `workflow_definition_version`   int      NOT NULL DEFAULT 0,
+    `task_definition_code`         bigint(20)   NOT NULL DEFAULT 0,
+    `task_definition_version`      int      NOT NULL DEFAULT 0,
+    `dept_project_code`            bigint(20)   NOT NULL DEFAULT 0,
+    `dept_workflow_definition_code` bigint(20)   NOT NULL DEFAULT 0,
+    `dept_task_definition_code`    bigint(20)   NOT NULL DEFAULT 0,
+    `create_time`                  datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
+    `update_time`                  datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+    PRIMARY KEY (`id`),
+    KEY                            `idx_workflow_code_version` (`workflow_definition_code`,`workflow_definition_version`),
+    KEY                            `idx_task_code_version` (`task_definition_code`,`task_definition_version`),
+    KEY                            `idx_dept_code` (`dept_project_code`,`dept_workflow_definition_code`,`dept_task_definition_code`)
+);
+
+
+-- ----------------------------
+-- Table structure for jdbc registry
+-- ----------------------------
+
+DROP TABLE IF EXISTS `t_ds_jdbc_registry_data`;
+CREATE TABLE `t_ds_jdbc_registry_data`
+(
+    `id`               bigint(11) NOT NULL AUTO_INCREMENT COMMENT 'primary key',
+    `data_key`         varchar(256) NOT NULL COMMENT 'key, like zookeeper node path',
+    `data_value`       text         NOT NULL COMMENT 'data, like zookeeper node value',
+    `data_type`        varchar(64)  NOT NULL COMMENT 'EPHEMERAL, PERSISTENT',
+    `client_id`        bigint       NOT NULL COMMENT 'client id',
+    `create_time`      timestamp    NOT NULL default current_timestamp COMMENT 'create time',
+    `last_update_time` timestamp    NOT NULL default current_timestamp COMMENT 'last update time',
+    PRIMARY KEY (`id`),
+    unique KEY `uk_t_ds_jdbc_registry_dataKey`(`data_key`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8;
+
+
+DROP TABLE IF EXISTS `t_ds_jdbc_registry_lock`;
+CREATE TABLE `t_ds_jdbc_registry_lock`
+(
+    `id`          bigint(11) NOT NULL AUTO_INCREMENT COMMENT 'primary key',
+    `lock_key`    varchar(256) NOT NULL COMMENT 'lock path',
+    `lock_owner`  varchar(256) NOT NULL COMMENT 'the lock owner, ip_processId',
+    `client_id`   bigint       NOT NULL COMMENT 'client id',
+    `create_time` timestamp    NOT NULL default current_timestamp COMMENT 'create time',
+    PRIMARY KEY (`id`),
+    unique KEY `uk_t_ds_jdbc_registry_lockKey`(`lock_key`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8;
+
+DROP TABLE IF EXISTS `t_ds_jdbc_registry_client_heartbeat`;
+CREATE TABLE `t_ds_jdbc_registry_client_heartbeat`
+(
+    `id`                  bigint(11) NOT NULL AUTO_INCREMENT COMMENT 'primary key',
+    `client_name`         varchar(256) NOT NULL COMMENT 'client name, ip_processId',
+    `last_heartbeat_time` bigint       NOT NULL COMMENT 'last heartbeat timestamp',
+    `connection_config`   text         NOT NULL COMMENT 'connection config',
+    `create_time`         timestamp    NOT NULL default current_timestamp COMMENT 'create time',
+    PRIMARY KEY (`id`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8;
+
+DROP TABLE IF EXISTS `t_ds_jdbc_registry_data_change_event`;
+CREATE TABLE `t_ds_jdbc_registry_data_change_event`
+(
+    `id`                 bigint(11) NOT NULL AUTO_INCREMENT COMMENT 'primary key',
+    `event_type`         varchar(64) NOT NULL COMMENT 'ADD, UPDATE, DELETE',
+    `jdbc_registry_data` text        NOT NULL COMMENT 'jdbc registry data',
+    `create_time`        timestamp   NOT NULL default current_timestamp COMMENT 'create time',
+    PRIMARY KEY (`id`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8;
+
+-- ----------------------------
+-- Table structure for jdbc registry
+-- ----------------------------
