@@ -35,25 +35,32 @@ import org.apache.dolphinscheduler.common.enums.CommandType;
 import org.apache.dolphinscheduler.common.utils.DateUtils;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.common.utils.placeholder.BusinessTimeUtils;
-import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
 import org.apache.dolphinscheduler.dao.entity.ProjectParameter;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
+import org.apache.dolphinscheduler.dao.entity.WorkflowInstance;
 import org.apache.dolphinscheduler.dao.mapper.ProjectParameterMapper;
+import org.apache.dolphinscheduler.extract.master.command.ICommandParam;
 import org.apache.dolphinscheduler.plugin.task.api.enums.DataType;
 import org.apache.dolphinscheduler.plugin.task.api.enums.Direct;
 import org.apache.dolphinscheduler.plugin.task.api.model.Property;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
 import org.apache.dolphinscheduler.plugin.task.api.utils.MapUtils;
 import org.apache.dolphinscheduler.plugin.task.api.utils.ParameterUtils;
+import org.apache.dolphinscheduler.plugin.task.api.utils.PropertyUtils;
+import org.apache.dolphinscheduler.plugin.task.api.utils.VarPoolUtils;
 
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
 
+import java.util.Collections;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.Iterator;
+import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.function.Function;
 import java.util.stream.Collectors;
 
 import javax.annotation.Nullable;
@@ -66,9 +73,6 @@ import org.springframework.stereotype.Component;
 @Component
 public class CuringParamsServiceImpl implements CuringParamsService {
 
-    @Autowired
-    private TimePlaceholderResolverExpandService timePlaceholderResolverExpandService;
-
     @Autowired
     private ProjectParameterMapper projectParameterMapper;
 
@@ -82,19 +86,10 @@ public class CuringParamsServiceImpl implements CuringParamsService {
         return ParameterUtils.convertParameterPlaceholders(val, paramMap);
     }
 
-    @Override
-    public boolean timeFunctionNeedExpand(String placeholderName) {
-        return timePlaceholderResolverExpandService.timeFunctionNeedExpand(placeholderName);
-    }
-
-    @Override
-    public String timeFunctionExtension(Integer processInstanceId, String timezone, String placeholderName) {
-        return timePlaceholderResolverExpandService.timeFunctionExtension(processInstanceId, timezone, placeholderName);
-    }
-
     /**
      * here it is judged whether external expansion calculation is required and the calculation result is obtained
-     * @param processInstanceId
+     *
+     * @param workflowInstanceId
      * @param globalParamMap
      * @param globalParamList
      * @param commandType
@@ -103,7 +98,7 @@ public class CuringParamsServiceImpl implements CuringParamsService {
      * @return
      */
     @Override
-    public String curingGlobalParams(Integer processInstanceId, Map<String, String> globalParamMap,
+    public String curingGlobalParams(Integer workflowInstanceId, Map<String, String> globalParamMap,
                                      List<Property> globalParamList, CommandType commandType, Date scheduleTime,
                                      String timezone) {
         if (globalParamList == null || globalParamList.isEmpty()) {
@@ -127,10 +122,6 @@ public class CuringParamsServiceImpl implements CuringParamsService {
             String val = entry.getValue();
             if (val.contains(Constants.FUNCTION_START_WITH)) {
                 String str = val;
-                // whether external scaling calculation is required
-                if (timeFunctionNeedExpand(val)) {
-                    str = timeFunctionExtension(processInstanceId, timezone, val);
-                }
                 resolveMap.put(entry.getKey(), str);
             }
         }
@@ -150,9 +141,11 @@ public class CuringParamsServiceImpl implements CuringParamsService {
             return new HashMap<>();
         }
         String startParamJson = cmdParam.get(CommandKeyConstants.CMD_PARAM_START_PARAMS);
-        Map<String, String> startParamMap = JSONUtils.toMap(startParamJson);
-        return startParamMap.entrySet().stream().collect(Collectors.toMap(Map.Entry::getKey,
-                entry -> new Property(entry.getKey(), Direct.IN, DataType.VARCHAR, entry.getValue())));
+        List<Property> propertyList = PropertyUtils.startParamsTransformPropertyList(startParamJson);
+        if (CollectionUtils.isEmpty(propertyList)) {
+            return new HashMap<>();
+        }
+        return propertyList.stream().collect(Collectors.toMap(Property::getProp, Function.identity()));
     }
 
     @Override
@@ -167,38 +160,44 @@ public class CuringParamsServiceImpl implements CuringParamsService {
     }
 
     /**
-     * the global parameters and local parameters used in the worker will be prepared here, and built-in parameters.
+     * Generate prepare params include project params, global parameters, local parameters, built-in parameters, varpool, start-up params.
+     * <p> The priority of the parameters is as follows:
+     * <p> varpool > command parameters > local parameters > global parameters > project parameters > built-in parameters
+     * todo: Use TaskRuntimeParams to represent this.
      *
      * @param taskInstance
      * @param parameters
-     * @param processInstance
+     * @param workflowInstance
+     * @param projectName
+     * @param workflowDefinitionName
      * @return
      */
     @Override
     public Map<String, Property> paramParsingPreparation(@NonNull TaskInstance taskInstance,
                                                          @NonNull AbstractParameters parameters,
-                                                         @NonNull ProcessInstance processInstance) {
+                                                         @NonNull WorkflowInstance workflowInstance,
+                                                         String projectName,
+                                                         String workflowDefinitionName) {
         Map<String, Property> prepareParamsMap = new HashMap<>();
 
         // assign value to definedParams here
-        Map<String, String> globalParamsMap = setGlobalParamsMap(processInstance);
-        Map<String, Property> globalParams = ParameterUtils.getUserDefParamsMap(globalParamsMap);
+        Map<String, Property> globalParams = parseGlobalParamsMap(workflowInstance);
 
         // combining local and global parameters
         Map<String, Property> localParams = parameters.getInputLocalParametersMap();
 
         // stream pass params
-        parameters.setVarPool(taskInstance.getVarPool());
-        Map<String, Property> varParams = parameters.getVarPoolMap();
+        List<Property> varPools = parseVarPool(taskInstance);
 
         // if it is a complement,
         // you need to pass in the task instance id to locate the time
         // of the process instance complement
-        Map<String, String> cmdParam = JSONUtils.toMap(processInstance.getCommandParam());
-        String timeZone = cmdParam.get(Constants.SCHEDULE_TIMEZONE);
+        ICommandParam commandParam = JSONUtils.parseObject(workflowInstance.getCommandParam(), ICommandParam.class);
+        String timeZone = commandParam.getTimeZone();
 
         // built-in params
-        Map<String, String> builtInParams = setBuiltInParamsMap(taskInstance, timeZone);
+        Map<String, String> builtInParams =
+                setBuiltInParamsMap(taskInstance, workflowInstance, timeZone, projectName, workflowDefinitionName);
 
         // project-level params
         Map<String, Property> projectParams = getProjectParameterMap(taskInstance.getProjectCode());
@@ -215,16 +214,24 @@ public class CuringParamsServiceImpl implements CuringParamsService {
             prepareParamsMap.putAll(globalParams);
         }
 
-        if (MapUtils.isNotEmpty(varParams)) {
-            prepareParamsMap.putAll(varParams);
-        }
-
         if (MapUtils.isNotEmpty(localParams)) {
             prepareParamsMap.putAll(localParams);
         }
 
-        if (MapUtils.isNotEmpty(cmdParam)) {
-            prepareParamsMap.putAll(parseWorkflowStartParam(cmdParam));
+        if (CollectionUtils.isNotEmpty(commandParam.getCommandParams())) {
+            prepareParamsMap.putAll(commandParam.getCommandParams().stream()
+                    .collect(Collectors.toMap(Property::getProp, Function.identity())));
+        }
+
+        if (CollectionUtils.isNotEmpty(varPools)) {
+            // overwrite the in parameter by varPool
+            for (Property varPool : varPools) {
+                Property property = prepareParamsMap.get(varPool.getProp());
+                if (property == null || property.getDirect() != Direct.IN) {
+                    continue;
+                }
+                property.setValue(varPool.getValue());
+            }
         }
 
         Iterator<Map.Entry<String, Property>> iter = prepareParamsMap.entrySet().iterator();
@@ -240,20 +247,16 @@ public class CuringParamsServiceImpl implements CuringParamsService {
                  *  and there are no variables in them.
                  */
                 String val = property.getValue();
-                // whether external scaling calculation is required
-                if (timeFunctionNeedExpand(val)) {
-                    val = timeFunctionExtension(taskInstance.getProcessInstanceId(), timeZone, val);
-                } else {
-                    // handle some chain parameter assign, such as `{"var1": "${var2}", "var2": 1}` should be convert to
-                    // `{"var1": 1, "var2": 1}`
-                    val = convertParameterPlaceholders(val, prepareParamsMap);
-                }
+
+                // handle some chain parameter assign, such as `{"var1": "${var2}", "var2": 1}` should be convert to
+                // `{"var1": 1, "var2": 1}`
+                val = convertParameterPlaceholders(val, prepareParamsMap);
                 property.setValue(val);
             }
         }
 
         // put schedule time param to params map
-        Map<String, Property> paramsMap = preBuildBusinessParams(processInstance);
+        Map<String, Property> paramsMap = preBuildBusinessParams(workflowInstance);
         if (MapUtils.isNotEmpty(paramsMap)) {
             prepareParamsMap.putAll(paramsMap);
         }
@@ -262,12 +265,19 @@ public class CuringParamsServiceImpl implements CuringParamsService {
 
     /**
      * build all built-in parameters
+     *
      * @param taskInstance
      * @param timeZone
+     * @param projectName
+     * @param workflowDefinitionName
      */
-    private Map<String, String> setBuiltInParamsMap(@NonNull TaskInstance taskInstance, String timeZone) {
-        CommandType commandType = taskInstance.getProcessInstance().getCmdTypeIfComplement();
-        Date scheduleTime = taskInstance.getProcessInstance().getScheduleTime();
+    private Map<String, String> setBuiltInParamsMap(@NonNull TaskInstance taskInstance,
+                                                    WorkflowInstance workflowInstance,
+                                                    String timeZone,
+                                                    String projectName,
+                                                    String workflowDefinitionName) {
+        CommandType commandType = workflowInstance.getCmdTypeIfComplement();
+        Date scheduleTime = workflowInstance.getScheduleTime();
 
         Map<String, String> params = BusinessTimeUtils.getBusinessTime(commandType, scheduleTime, timeZone);
 
@@ -275,37 +285,38 @@ public class CuringParamsServiceImpl implements CuringParamsService {
             params.put(PARAMETER_TASK_EXECUTE_PATH, taskInstance.getExecutePath());
         }
         params.put(PARAMETER_TASK_INSTANCE_ID, Integer.toString(taskInstance.getId()));
-        params.put(PARAMETER_TASK_DEFINITION_NAME, taskInstance.getTaskDefine().getName());
-        params.put(PARAMETER_TASK_DEFINITION_CODE, Long.toString(taskInstance.getTaskDefine().getCode()));
-        params.put(PARAMETER_WORKFLOW_INSTANCE_ID, Integer.toString(taskInstance.getProcessInstance().getId()));
-        params.put(PARAMETER_WORKFLOW_DEFINITION_NAME,
-                taskInstance.getProcessInstance().getProcessDefinition().getName());
-        params.put(PARAMETER_WORKFLOW_DEFINITION_CODE,
-                Long.toString(taskInstance.getProcessInstance().getProcessDefinition().getCode()));
-        params.put(PARAMETER_PROJECT_NAME, taskInstance.getProcessInstance().getProcessDefinition().getProjectName());
-        params.put(PARAMETER_PROJECT_CODE,
-                Long.toString(taskInstance.getProcessInstance().getProcessDefinition().getProjectCode()));
+        params.put(PARAMETER_TASK_DEFINITION_NAME, taskInstance.getName());
+        params.put(PARAMETER_TASK_DEFINITION_CODE, Long.toString(taskInstance.getTaskCode()));
+        params.put(PARAMETER_WORKFLOW_INSTANCE_ID, Integer.toString(taskInstance.getWorkflowInstanceId()));
+        params.put(PARAMETER_WORKFLOW_DEFINITION_NAME, workflowDefinitionName);
+        params.put(PARAMETER_WORKFLOW_DEFINITION_CODE, Long.toString(workflowInstance.getWorkflowDefinitionCode()));
+        params.put(PARAMETER_PROJECT_NAME, projectName);
+        params.put(PARAMETER_PROJECT_CODE, Long.toString(workflowInstance.getProjectCode()));
         return params;
     }
-    private Map<String, String> setGlobalParamsMap(ProcessInstance processInstance) {
-        Map<String, String> globalParamsMap = new HashMap<>(16);
 
-        // global params string
-        String globalParamsStr = processInstance.getGlobalParams();
-        if (globalParamsStr != null) {
-            List<Property> globalParamsList = JSONUtils.toList(globalParamsStr, Property.class);
-            globalParamsMap
-                    .putAll(globalParamsList.stream().collect(Collectors.toMap(Property::getProp, Property::getValue)));
+    private Map<String, Property> parseGlobalParamsMap(WorkflowInstance workflowInstance) {
+        final Map<String, Property> globalParametersMaps = new LinkedHashMap<>();
+        if (StringUtils.isNotEmpty(workflowInstance.getGlobalParams())) {
+            JSONUtils.toList(workflowInstance.getGlobalParams(), Property.class)
+                    .forEach(property -> globalParametersMaps.put(property.getProp(), property));
         }
-        return globalParamsMap;
+        return globalParametersMaps;
+    }
+
+    private List<Property> parseVarPool(TaskInstance taskInstance) {
+        if (StringUtils.isNotEmpty(taskInstance.getVarPool())) {
+            return VarPoolUtils.deserializeVarPool(taskInstance.getVarPool());
+        }
+        return Collections.emptyList();
     }
 
     @Override
-    public Map<String, Property> preBuildBusinessParams(ProcessInstance processInstance) {
+    public Map<String, Property> preBuildBusinessParams(WorkflowInstance workflowInstance) {
         Map<String, Property> paramsMap = new HashMap<>();
         // replace variable TIME with $[YYYYmmddd...] in shell file when history run job and batch complement job
-        if (processInstance.getScheduleTime() != null) {
-            Date date = processInstance.getScheduleTime();
+        if (workflowInstance.getScheduleTime() != null) {
+            Date date = workflowInstance.getScheduleTime();
             String dateTime = DateUtils.format(date, DateConstants.PARAMETER_FORMAT_TIME, null);
             Property p = new Property();
             p.setValue(dateTime);
@@ -323,7 +334,7 @@ public class CuringParamsServiceImpl implements CuringParamsService {
         projectParameterList.forEach(projectParameter -> {
             Property property = new Property(projectParameter.getParamName(),
                     Direct.IN,
-                    DataType.VARCHAR,
+                    Enum.valueOf(DataType.class, projectParameter.getParamDataType()),
                     projectParameter.getParamValue());
             result.put(projectParameter.getParamName(), property);
         });
