@@ -28,20 +28,16 @@ import org.apache.commons.collections4.CollectionUtils;
 
 import java.io.IOException;
 import java.util.List;
-import java.util.Map;
 import java.util.stream.Collectors;
 
+import lombok.extern.slf4j.Slf4j;
+
+@Slf4j
 public class FlinkStreamTask extends FlinkTask implements StreamTask {
 
-    /**
-     * flink parameters
-     */
     private FlinkStreamParameters flinkParameters;
 
-    /**
-     * taskExecutionContext
-     */
-    private TaskExecutionContext taskExecutionContext;
+    private final TaskExecutionContext taskExecutionContext;
 
     public FlinkStreamTask(TaskExecutionContext taskExecutionContext) {
         super(taskExecutionContext);
@@ -73,11 +69,6 @@ public class FlinkStreamTask extends FlinkTask implements StreamTask {
         return args.stream().collect(Collectors.joining(" "));
     }
 
-    @Override
-    protected Map<String, String> getProperties() {
-        return taskExecutionContext.getDefinedParams();
-    }
-
     @Override
     public AbstractParameters getParameters() {
         return flinkParameters;
