@@ -20,9 +20,9 @@ package org.apache.dolphinscheduler.plugin.task.flink;
 import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
 import org.apache.dolphinscheduler.plugin.task.api.model.Property;
 import org.apache.dolphinscheduler.plugin.task.api.model.ResourceInfo;
-import org.apache.dolphinscheduler.plugin.task.api.parser.ParamUtils;
-import org.apache.dolphinscheduler.plugin.task.api.parser.ParameterUtils;
+import org.apache.dolphinscheduler.plugin.task.api.resource.ResourceContext;
 import org.apache.dolphinscheduler.plugin.task.api.utils.ArgsUtils;
+import org.apache.dolphinscheduler.plugin.task.api.utils.ParameterUtils;
 
 import org.apache.commons.lang3.StringUtils;
 
@@ -94,7 +94,8 @@ public class FlinkArgsUtils {
      *
      * @return argument list
      */
-    private static List<String> buildRunCommandLineForSql(TaskExecutionContext taskExecutionContext, FlinkParameters flinkParameters) {
+    private static List<String> buildRunCommandLineForSql(TaskExecutionContext taskExecutionContext,
+                                                          FlinkParameters flinkParameters) {
         List<String> args = new ArrayList<>();
 
         args.add(FlinkConstants.FLINK_SQL_COMMAND);
@@ -119,7 +120,8 @@ public class FlinkArgsUtils {
     public static List<String> buildInitOptionsForSql(FlinkParameters flinkParameters) {
         List<String> initOptions = new ArrayList<>();
 
-        FlinkDeployMode deployMode = Optional.ofNullable(flinkParameters.getDeployMode()).orElse(FlinkDeployMode.CLUSTER);
+        FlinkDeployMode deployMode =
+                Optional.ofNullable(flinkParameters.getDeployMode()).orElse(FlinkDeployMode.CLUSTER);
 
         /**
          * Currently flink sql on yarn only supports yarn-per-job mode
@@ -127,9 +129,12 @@ public class FlinkArgsUtils {
         if (FlinkDeployMode.LOCAL == deployMode) {
             // execution.target
             initOptions.add(String.format(FlinkConstants.FLINK_FORMAT_EXECUTION_TARGET, FlinkConstants.FLINK_LOCAL));
+        } else if (FlinkDeployMode.STANDALONE == deployMode) {
+            // standalone exec
         } else {
             // execution.target
-            initOptions.add(String.format(FlinkConstants.FLINK_FORMAT_EXECUTION_TARGET, FlinkConstants.FLINK_YARN_PER_JOB));
+            initOptions.add(
+                    String.format(FlinkConstants.FLINK_FORMAT_EXECUTION_TARGET, FlinkConstants.FLINK_YARN_PER_JOB));
 
             // taskmanager.numberOfTaskSlots
             int slot = flinkParameters.getSlot();
@@ -140,25 +145,28 @@ public class FlinkArgsUtils {
             // yarn.application.name
             String appName = flinkParameters.getAppName();
             if (StringUtils.isNotEmpty(appName)) {
-                initOptions.add(String.format(FlinkConstants.FLINK_FORMAT_YARN_APPLICATION_NAME, ArgsUtils.escape(appName)));
+                initOptions.add(
+                        String.format(FlinkConstants.FLINK_FORMAT_YARN_APPLICATION_NAME, ArgsUtils.escape(appName)));
             }
 
             // jobmanager.memory.process.size
             String jobManagerMemory = flinkParameters.getJobManagerMemory();
             if (StringUtils.isNotEmpty(jobManagerMemory)) {
-                initOptions.add(String.format(FlinkConstants.FLINK_FORMAT_JOBMANAGER_MEMORY_PROCESS_SIZE, jobManagerMemory));
+                initOptions.add(
+                        String.format(FlinkConstants.FLINK_FORMAT_JOBMANAGER_MEMORY_PROCESS_SIZE, jobManagerMemory));
             }
 
             // taskmanager.memory.process.size
             String taskManagerMemory = flinkParameters.getTaskManagerMemory();
             if (StringUtils.isNotEmpty(taskManagerMemory)) {
-                initOptions.add(String.format(FlinkConstants.FLINK_FORMAT_TASKMANAGER_MEMORY_PROCESS_SIZE, taskManagerMemory));
+                initOptions.add(
+                        String.format(FlinkConstants.FLINK_FORMAT_TASKMANAGER_MEMORY_PROCESS_SIZE, taskManagerMemory));
             }
 
             // yarn.application.queue
-            String queue = flinkParameters.getQueue();
-            if (StringUtils.isNotEmpty(queue)) {
-                initOptions.add(String.format(FlinkConstants.FLINK_FORMAT_YARN_APPLICATION_QUEUE, queue));
+            String yarnQueue = flinkParameters.getYarnQueue();
+            if (StringUtils.isNotEmpty(yarnQueue)) {
+                initOptions.add(String.format(FlinkConstants.FLINK_FORMAT_YARN_APPLICATION_QUEUE, yarnQueue));
             }
         }
 
@@ -171,7 +179,8 @@ public class FlinkArgsUtils {
         return initOptions;
     }
 
-    private static List<String> buildRunCommandLineForOthers(TaskExecutionContext taskExecutionContext, FlinkParameters flinkParameters) {
+    private static List<String> buildRunCommandLineForOthers(TaskExecutionContext taskExecutionContext,
+                                                             FlinkParameters flinkParameters) {
         List<String> args = new ArrayList<>();
 
         args.add(FlinkConstants.FLINK_COMMAND);
@@ -180,23 +189,27 @@ public class FlinkArgsUtils {
         // build run command
         switch (deployMode) {
             case CLUSTER:
-                if (FLINK_VERSION_AFTER_OR_EQUALS_1_12.equals(flinkVersion) || FLINK_VERSION_AFTER_OR_EQUALS_1_13.equals(flinkVersion)) {
-                    args.add(FlinkConstants.FLINK_RUN);  //run
-                    args.add(FlinkConstants.FLINK_EXECUTION_TARGET);  //-t
-                    args.add(FlinkConstants.FLINK_YARN_PER_JOB);  //yarn-per-job
+                if (FLINK_VERSION_AFTER_OR_EQUALS_1_12.equals(flinkVersion)
+                        || FLINK_VERSION_AFTER_OR_EQUALS_1_13.equals(flinkVersion)) {
+                    args.add(FlinkConstants.FLINK_RUN); // run
+                    args.add(FlinkConstants.FLINK_EXECUTION_TARGET); // -t
+                    args.add(FlinkConstants.FLINK_YARN_PER_JOB); // yarn-per-job
                 } else {
-                    args.add(FlinkConstants.FLINK_RUN);  //run
-                    args.add(FlinkConstants.FLINK_RUN_MODE);  //-m
-                    args.add(FlinkConstants.FLINK_YARN_CLUSTER);  //yarn-cluster
+                    args.add(FlinkConstants.FLINK_RUN); // run
+                    args.add(FlinkConstants.FLINK_RUN_MODE); // -m
+                    args.add(FlinkConstants.FLINK_YARN_CLUSTER); // yarn-cluster
                 }
                 break;
             case APPLICATION:
-                args.add(FlinkConstants.FLINK_RUN_APPLICATION);  //run-application
-                args.add(FlinkConstants.FLINK_EXECUTION_TARGET);  //-t
-                args.add(FlinkConstants.FLINK_YARN_APPLICATION);  //yarn-application
+                args.add(FlinkConstants.FLINK_RUN_APPLICATION); // run-application
+                args.add(FlinkConstants.FLINK_EXECUTION_TARGET); // -t
+                args.add(FlinkConstants.FLINK_YARN_APPLICATION); // yarn-application
                 break;
             case LOCAL:
-                args.add(FlinkConstants.FLINK_RUN);  //run
+                args.add(FlinkConstants.FLINK_RUN); // run
+                break;
+            case STANDALONE:
+                args.add(FlinkConstants.FLINK_RUN); // run
                 break;
         }
 
@@ -209,11 +222,11 @@ public class FlinkArgsUtils {
                 int slot = flinkParameters.getSlot();
                 if (slot > 0) {
                     args.add(FlinkConstants.FLINK_YARN_SLOT);
-                    args.add(String.format("%d", slot));   //-ys
+                    args.add(String.format("%d", slot)); // -ys
                 }
 
                 String appName = flinkParameters.getAppName();
-                if (StringUtils.isNotEmpty(appName)) { //-ynm
+                if (StringUtils.isNotEmpty(appName)) { // -ynm
                     args.add(FlinkConstants.FLINK_APP_NAME);
                     args.add(ArgsUtils.escape(appName));
                 }
@@ -221,7 +234,7 @@ public class FlinkArgsUtils {
                 // judge flink version, the parameter -yn has removed from flink 1.10
                 if (flinkVersion == null || FLINK_VERSION_BEFORE_1_10.equals(flinkVersion)) {
                     int taskManager = flinkParameters.getTaskManager();
-                    if (taskManager > 0) {                        //-yn
+                    if (taskManager > 0) { // -yn
                         args.add(FlinkConstants.FLINK_TASK_MANAGE);
                         args.add(String.format("%d", taskManager));
                     }
@@ -229,7 +242,7 @@ public class FlinkArgsUtils {
                 String jobManagerMemory = flinkParameters.getJobManagerMemory();
                 if (StringUtils.isNotEmpty(jobManagerMemory)) {
                     args.add(FlinkConstants.FLINK_JOB_MANAGE_MEM);
-                    args.add(jobManagerMemory); //-yjm
+                    args.add(jobManagerMemory); // -yjm
                 }
 
                 String taskManagerMemory = flinkParameters.getTaskManagerMemory();
@@ -241,15 +254,18 @@ public class FlinkArgsUtils {
                 break;
             case LOCAL:
                 break;
+            case STANDALONE:
+                break;
         }
 
         int parallelism = flinkParameters.getParallelism();
         if (parallelism > 0) {
             args.add(FlinkConstants.FLINK_PARALLELISM);
-            args.add(String.format("%d", parallelism));   // -p
+            args.add(String.format("%d", parallelism)); // -p
         }
 
-        // If the job is submitted in attached mode, perform a best-effort cluster shutdown when the CLI is terminated abruptly
+        // If the job is submitted in attached mode, perform a best-effort cluster shutdown when the CLI is terminated
+        // abruptly
         // The task status will be synchronized with the cluster job status
         args.add(FlinkConstants.FLINK_SHUTDOWN_ON_ATTACHED_EXIT); // -sae
 
@@ -263,23 +279,24 @@ public class FlinkArgsUtils {
         ProgramType programType = flinkParameters.getProgramType();
         String mainClass = flinkParameters.getMainClass();
         if (programType != null && programType != ProgramType.PYTHON && StringUtils.isNotEmpty(mainClass)) {
-            args.add(FlinkConstants.FLINK_MAIN_CLASS);    //-c
-            args.add(flinkParameters.getMainClass());          //main class
+            args.add(FlinkConstants.FLINK_MAIN_CLASS); // -c
+            args.add(flinkParameters.getMainClass()); // main class
         }
 
         ResourceInfo mainJar = flinkParameters.getMainJar();
         if (mainJar != null) {
             // -py
-            if(ProgramType.PYTHON == programType) {
+            if (ProgramType.PYTHON == programType) {
                 args.add(FlinkConstants.FLINK_PYTHON);
             }
-            args.add(mainJar.getRes());
+            ResourceContext resourceContext = taskExecutionContext.getResourceContext();
+            args.add(resourceContext.getResourceItem(mainJar.getResourceName()).getResourceAbsolutePathInLocal());
         }
 
         String mainArgs = flinkParameters.getMainArgs();
         if (StringUtils.isNotEmpty(mainArgs)) {
             Map<String, Property> paramsMap = taskExecutionContext.getPrepareParamsMap();
-            args.add(ParameterUtils.convertParameterPlaceholders(mainArgs, ParamUtils.convert(paramsMap)));
+            args.add(ParameterUtils.convertParameterPlaceholders(mainArgs, ParameterUtils.convert(paramsMap)));
         }
 
         return args;
@@ -305,7 +322,7 @@ public class FlinkArgsUtils {
     private static void doAddQueue(List<String> args, FlinkParameters flinkParameters, String option) {
         String others = flinkParameters.getOthers();
         if (StringUtils.isEmpty(others) || !others.contains(option)) {
-            String yarnQueue = flinkParameters.getQueue();
+            String yarnQueue = flinkParameters.getYarnQueue();
             if (StringUtils.isNotEmpty(yarnQueue)) {
                 switch (option) {
                     case FlinkConstants.FLINK_YARN_QUEUE_FOR_TARGETS:
